@@ -34,7 +34,6 @@ import java.util.Map;
 import java.util.Vector;
 
 import javax.swing.*;
-import javax.swing.SwingWorker.StateValue;
 import javax.swing.text.Segment;
 
 import org.gjt.sp.jedit.browser.VFSBrowser;
@@ -43,7 +42,6 @@ import org.gjt.sp.jedit.buffer.FoldHandler;
 import org.gjt.sp.jedit.buffer.JEditBuffer;
 import org.gjt.sp.jedit.bufferio.BufferAutosaveRequest;
 import org.gjt.sp.jedit.bufferio.BufferIORequest;
-import org.gjt.sp.jedit.bufferio.IoTask;
 import org.gjt.sp.jedit.bufferio.MarkersSaveRequest;
 import org.gjt.sp.jedit.bufferset.BufferSet;
 import org.gjt.sp.jedit.gui.DockableWindowManager;
@@ -52,6 +50,7 @@ import org.gjt.sp.jedit.io.VFS;
 import org.gjt.sp.jedit.io.VFSFile;
 import org.gjt.sp.jedit.io.VFSManager;
 import org.gjt.sp.jedit.msg.BufferUpdate;
+import org.gjt.sp.jedit.msg.PropertiesChanged;
 import org.gjt.sp.jedit.syntax.ModeProvider;
 import org.gjt.sp.jedit.syntax.ParserRuleSet;
 import org.gjt.sp.jedit.syntax.TokenHandler;
@@ -92,7 +91,7 @@ import org.gjt.sp.util.ThreadUtilities;
 
  *
  * @author Slava Pestov
- * @version $Id: Buffer.java 24087 2015-09-19 20:56:09Z daleanson $
+ * @version $Id: Buffer.java 24849 2018-03-27 16:24:10Z vampire0 $
  */
 public class Buffer extends JEditBuffer
 {
@@ -197,7 +196,10 @@ public class Buffer extends JEditBuffer
 
 		final boolean loadAutosave;
 
-		if(reload || !getFlag(NEW_FILE))
+		boolean autosaveUntitled = jEdit.getBooleanProperty("autosaveUntitled");
+
+		// for untitled: re-read autosave file if enabled
+		if(reload || !getFlag(NEW_FILE) || (isUntitled() && autosaveUntitled))
 		{
 			if(file != null)
 				modTime = file.lastModified();
@@ -226,7 +228,7 @@ public class Buffer extends JEditBuffer
 				// NEW_FILE flag
 				if(reload || !getFlag(NEW_FILE))
 				{
-					if(!vfs.load(view,this,path))
+					if(!vfs.load(view,this,path, isUntitled()))
 					{
 						setLoading(false);
 						return false;
@@ -348,11 +350,33 @@ public class Buffer extends JEditBuffer
 	 */
 	public void autosave()
 	{
-		if(autosaveFile == null || !getFlag(AUTOSAVE_DIRTY)
+		autosave(false);
+	} //}}}
+
+	//{{{ autosave() method
+	/**
+	 * Autosaves this buffer.
+	 *
+	 * @param force save even if AUTOSAVE_DIRTY not set
+	 * @since jEdit 5.5pre1
+	 */
+	public void autosave(boolean force)
+	{
+
+		if(autosaveFile == null || (!getFlag(AUTOSAVE_DIRTY) && !force)
 			|| !isDirty() || isPerformingIO() ||
 			!autosaveFile.getParentFile().exists())
 			return;
 
+		// re-set autosave file path, based on the path at the settings
+		File autosaveFileOriginal = autosaveFile;
+		setAutosaveFile();
+
+		// if autosave path settings changed, delete the old file
+		if(autosaveFile != null && !autosaveFileOriginal.toString().equals(autosaveFile.toString())) {
+			autosaveFileOriginal.delete();
+		}
+
 		setFlag(AUTOSAVE_DIRTY,false);
 
 		ThreadUtilities.runInBackground(new BufferAutosaveRequest(
@@ -372,12 +396,12 @@ public class Buffer extends JEditBuffer
 	public boolean saveAs(View view, boolean rename)
 	{
 		String fileSavePath = path;
-		if (jEdit.getBooleanProperty("saveAsUsesFSB")) 
+		if (jEdit.getBooleanProperty("saveAsUsesFSB"))
 		{
 			DockableWindowManager dwm = view.getDockableWindowManager();
 			Component comp = dwm.getDockable("vfs.browser");
 			VFSBrowser browser = (VFSBrowser) comp;
-			if (browser != null) 
+			if (browser != null)
 				fileSavePath = browser.getDirectory() + "/";
 		}
 		String[] files = GUIUtilities.showVFSFileDialog(view, fileSavePath, VFSBrowser.SAVE_DIALOG,false);
@@ -443,7 +467,7 @@ public class Buffer extends JEditBuffer
 			GUIUtilities.error(view,"buffer-multiple-io",null);
 			return false;
 		}
-		
+
 		setBooleanProperty(BufferIORequest.ERROR_OCCURRED,false);
 
 		if(path == null && getFlag(NEW_FILE))
@@ -643,7 +667,8 @@ public class Buffer extends JEditBuffer
 		// because for a moment newModTime will be greater than
 		// oldModTime, due to the multithreading
 		// - only supported on local file system
-		if(!isPerformingIO() && file != null && !getFlag(NEW_FILE))
+		// - for untitled, do not check
+		if(!isPerformingIO() && file != null && !getFlag(NEW_FILE) && !isUntitled())
 		{
 			boolean newReadOnly = file.exists() && !file.canWrite();
 			if(newReadOnly != isFileReadOnly())
@@ -894,6 +919,17 @@ public class Buffer extends JEditBuffer
 		return getFlag(UNTITLED);
 	} //}}}
 
+	//{{{ setUntitled() method
+	/**
+	 *
+	 * @param untitled untitled value to set
+	 * @since jEdit 5.5pre1
+	 */
+	protected void setUntitled(boolean untitled)
+	{
+		setFlag(UNTITLED, untitled);
+	} //}}}
+
 	//{{{ setDirty() method
 	/**
 	 * Sets the 'dirty' (changed since last save) flag of this buffer.
@@ -902,11 +938,10 @@ public class Buffer extends JEditBuffer
 	public void setDirty(boolean d)
 	{
 		boolean old_d = isDirty();
-		if (isUntitled() && jEdit.getBooleanProperty("suppressNotSavedConfirmUntitled"))
-			d = false;
 		if (d && getLength() == initialLength)
 		{
-			if (jEdit.getBooleanProperty("useMD5forDirtyCalculation"))
+			// for untitled, do not check if the content existed before
+			if (jEdit.getBooleanProperty("useMD5forDirtyCalculation") && !isUntitled())
 				d = !Arrays.equals(calculateHash(), md5hash);
 		}
 		super.setDirty(d);
@@ -944,6 +979,60 @@ public class Buffer extends JEditBuffer
 		return getFlag(TEMPORARY);
 	} //}}}
 
+	//{{{ isBackup() method
+	/**
+	 * @return if this buffer most probably contains backup file
+	 */
+	public boolean isBackup()
+	{
+		return MiscUtilities.isBackup(MiscUtilities.getFileName(getPath()));
+	} //}}}
+
+
+	public boolean isEditable()
+	{
+		return super.isEditable() && !isLocked(); // respects "locked" property
+	}
+
+	//{{{ isLocked() method
+	/**
+	 * @return if this buffer is locked for editing
+	 */
+	public boolean isLocked()
+	{
+		return getBooleanProperty("locked", false);
+	}
+	//}}}
+
+	//{{{ setLocked() method
+	/**
+	 * Changes locked state of the buffer.
+	 * @param locked true to lock, false to unlock
+	 */
+	public void setLocked(boolean locked)
+	{
+		setBooleanProperty("locked", locked);
+		propertiesChanged();
+	}
+	//}}}
+
+	//{{{ toggleLocked() method
+	/**
+	 * Toggles locked state of the buffer.
+	 * @param view We show a message in the view's status bar
+	 */
+	public void toggleLocked(View view)
+	{
+		setLocked(!isLocked());
+
+		view.getStatus().setMessageAndClear(
+				jEdit.getProperty("view.status.locked-changed",
+						new Integer[] { isLocked() ? 1 : 0 }));
+		EditBus.send(new PropertiesChanged(Buffer.this));
+
+	}
+	//}}}
+
 	//{{{ getIcon() method
 	/**
 	 * @return this buffer's icon.
@@ -953,7 +1042,7 @@ public class Buffer extends JEditBuffer
 	{
 		if(isDirty())
 			return GUIUtilities.loadIcon("dirty.gif");
-		else if(isReadOnly())
+		else if(isReadOnly() || isLocked())
 			return GUIUtilities.loadIcon("readonly.gif");
 		else if(getFlag(NEW_FILE))
 			return GUIUtilities.loadIcon("new.gif");
@@ -1010,7 +1099,7 @@ public class Buffer extends JEditBuffer
 		// Try returning it as an integer first
 		try
 		{
-			retVal = new Integer(value);
+			retVal = Integer.valueOf(value);
 		}
 		catch(NumberFormatException nf)
 		{
@@ -1048,7 +1137,7 @@ public class Buffer extends JEditBuffer
 		setProperty("wrap",wrap);
 		propertiesChanged();
 	} //}}}
-	
+
 	//{{{ toggleAutoIndent() method
 	/**
 	 * Toggles automatic indentation on and off.
@@ -1065,12 +1154,12 @@ public class Buffer extends JEditBuffer
 		else if (indent.equals("full"))
 			indent = "none";
 		setProperty("autoIndent", indent);
-		
+
 		view.getStatus().setMessageAndClear(
 			jEdit.getProperty("view.status.autoindent-changed",
 				new String[] {indent}));
 	}
-			
+
 
 	//{{{ toggleLineSeparator() method
 	/**
@@ -1140,7 +1229,7 @@ public class Buffer extends JEditBuffer
 	//}}}
 
 	//}}}
-	
+
 	//{{{ Edit modes, syntax highlighting
 
 	//{{{ setMode() method
@@ -1170,12 +1259,12 @@ public class Buffer extends JEditBuffer
 				mode.loadIfNecessary();
 				boolean contextInsensitive = mode.getBooleanProperty("contextInsensitive");
 				String largeFileMode = jEdit.getProperty("largefilemode", "ask");
-				
+
 				if ("ask".equals(largeFileMode))
 				{
 					if (!contextInsensitive)
 					{
-						// the context is not insensitive 
+						// the context is not insensitive
 						JTextPane tp = new JTextPane();
 						tp.setEditable(false);
 						tp.setText(jEdit.getProperty("largeBufferDialog.message"));
@@ -1642,32 +1731,23 @@ public class Buffer extends JEditBuffer
 
 	//{{{ Buffer constructor
 	Buffer(String path, boolean newFile, boolean temp, Map props)
+	{
+		this(path, newFile, temp, props, false);
+	}
+
+	//{{{ Buffer constructor
+	Buffer(String path, boolean newFile, boolean temp, Map props, boolean untitled)
 	{
 		super(props);
 		textTokenMarker = jEdit.getMode("text").getTokenMarker();
 		markers = new Vector<Marker>();
 
 		setFlag(TEMPORARY,temp);
+		setFlag(UNTITLED,untitled);
 
 		// this must be called before any EditBus messages are sent
 		setPath(path);
 
-		/* Magic: UNTITLED is only set if newFile param to
-		 * constructor is set, NEW_FILE is also set if file
-		 * doesn't exist on disk.
-		 *
-		 * This is so that we can tell apart files created
-		 * with jEdit.newFile(), and those that just don't
-		 * exist on disk.
-		 *
-		 * Why do we need to tell the difference between the
-		 * two? jEdit.addBufferToList() checks if the only
-		 * opened buffer is an untitled buffer, and if so,
-		 * replaces it with the buffer to add. We don't want
-		 * this behavior to occur with files that don't
-		 * exist on disk; only untitled ones.
-		 */
-		setFlag(UNTITLED,newFile);
 		setFlag(NEW_FILE,newFile);
 		setFlag(AUTORELOAD,jEdit.getBooleanProperty("autoReload"));
 		setFlag(AUTORELOAD_DIALOG,jEdit.getBooleanProperty("autoReloadDialog"));
@@ -1686,11 +1766,29 @@ public class Buffer extends JEditBuffer
 	//{{{ close() method
 	void close()
 	{
-		setFlag(CLOSED,true);
+		close(false);
+	}
 
-		if(autosaveFile != null)
+	//{{{ close() method
+	/**
+	 * close the buffer
+	 * @param doNotSave when true, we do not want to keep the autosave even for untitled
+	 *	e.g.: we closed the buffer by hand
+	 */
+	void close(boolean doNotSave)
+	{
+		setFlag(CLOSED,true);
+                boolean autosaveUntitled = jEdit.getBooleanProperty("autosaveUntitled");
+
+		if(autosaveFile != null && (doNotSave || !(isUntitled() && autosaveUntitled)))
 			autosaveFile.delete();
 
+		// close az untitled buffer, but need to autosavesave
+		// except we close it manually and do not want to save
+		if ( !doNotSave && isUntitled() && autosaveUntitled ) {
+			autosave();
+		}
+
 		// notify clients with -wait
 		if(waitSocket != null)
 		{
@@ -1882,18 +1980,19 @@ public class Buffer extends JEditBuffer
 		if((vfs.getCapabilities() & VFS.WRITE_CAP) == 0)
 			setFileReadOnly(true);
 		name = vfs.getFileName(path);
+
 		directory = vfs.getParentOfPath(path);
 
 		if(vfs instanceof FileVFS)
 		{
 			file = new File(path);
 			symlinkPath = MiscUtilities.resolveSymlinks(path);
-
 			// if we don't do this, the autosave file won't be
 			// deleted after a save as
 			if(autosaveFile != null)
 				autosaveFile.delete();
-			autosaveFile = new File(file.getParent(),'#' + name + '#');
+
+			setAutosaveFile();
 		}
 		else
 		{
@@ -1905,6 +2004,16 @@ public class Buffer extends JEditBuffer
 		}
 	} //}}}
 
+	//{{{ setAutosaveFile() method
+	/**
+	 * Set the autosave file, based on the autosettings dir.
+	 * @since jEdit 5.5pre1
+	 */
+	private void setAutosaveFile()
+	{
+		File autosaveDir = MiscUtilities.prepareAutosaveDirectory(symlinkPath);
+		autosaveFile = new File(autosaveDir,'#' + name + '#');
+	} //}}}
 
 	//{{{ recoverAutosave() method
 	private boolean recoverAutosave(final View view)
@@ -1915,13 +2024,23 @@ public class Buffer extends JEditBuffer
 		// this method might get called at startup
 		GUIUtilities.hideSplashScreen();
 
+		boolean autosaveUntitled = jEdit.getBooleanProperty("autosaveUntitled");
+
 		final Object[] args = { autosaveFile.getPath() };
-		int result = GUIUtilities.confirm(view,"autosave-found",args,
+
+		int result;
+		// if it was an untitled autosave, recover without question
+		if (isUntitled() && autosaveUntitled) {
+			VFSManager.getFileVFS().load(view,this,autosaveFile.getPath(), isUntitled());
+			return true;
+		} else {
+			result = GUIUtilities.confirm(view,"autosave-found",args,
 			JOptionPane.YES_NO_OPTION,JOptionPane.WARNING_MESSAGE);
+		}
 
 		if(result == JOptionPane.YES_OPTION)
 		{
-			VFSManager.getFileVFS().load(view,this,autosaveFile.getPath());
+			VFSManager.getFileVFS().load(view,this,autosaveFile.getPath(), isUntitled());
 
 			// show this message when all I/O requests are
 			// complete
