@@ -80,7 +80,7 @@ import org.gjt.sp.util.ThreadUtilities;
  *
  * @author Slava Pestov
  * @author John Gellene (API documentation)
- * @version $Id: EditBus.java 21831 2012-06-18 22:54:17Z ezust $
+ * @version $Id: EditBus.java 24044 2015-09-03 13:34:54Z daleanson $
  *
  * @since jEdit 2.2pre6
  */
@@ -113,7 +113,7 @@ public class EditBus
 	public static @interface EBHandler
 	{
 		/**
-		 * Whether the message should match the exact type of
+		 * @return Whether the message should match the exact type of
 		 * the parameter, instead of a compatible type.
 		 */
 		boolean exact() default false;
@@ -238,7 +238,7 @@ public class EditBus
 				     EBMessage msg)
 		throws Exception
 	{
-		if (emh.handler != null)
+		if (emh.handler != null && emh.comp != null)
 			emh.handler.invoke(emh.comp, msg);
 		else
 		{
