@@ -23,12 +23,9 @@
 package org.gjt.sp.jedit;
 
 import java.io.Closeable;
-import java.io.StreamTokenizer;
-import java.io.StringReader;
 import java.io.IOException;
 import java.util.Collection;
 import java.util.LinkedList;
-import java.util.Stack;
 
 import org.gjt.sp.util.IOUtilities;
 import org.gjt.sp.util.Log;
@@ -40,7 +37,7 @@ import org.xml.sax.helpers.DefaultHandler;
 /** Manages persistence of open buffers and views across jEdit sessions.
  * @since jEdit 4.2pre1
  * @author Slava Pestov
- * @version $Id: PerspectiveManager.java 22357 2012-10-13 04:58:01Z ezust $
+ * @version $Id: PerspectiveManager.java 24800 2017-12-29 15:38:11Z ezust $
  */
 public class PerspectiveManager
 {
@@ -130,7 +127,7 @@ public class PerspectiveManager
 		Collection<Buffer> savedBuffers = new LinkedList<Buffer>();
 		for (Buffer buffer: buffers)
 		{
-			if (!buffer.isNewFile())
+			if (!buffer.isNewFile() || buffer.isUntitled())
 			{
 				savedBuffers.add(buffer);
 			}
@@ -159,8 +156,13 @@ public class PerspectiveManager
 				out.write(buffer.getAutoReload() ? "TRUE" : "FALSE");
 				out.write("\" AUTORELOAD_DIALOG=\"");
 				out.write(buffer.getAutoReloadDialog() ? "TRUE" : "FALSE");
+				out.write("\" UNTITLED=\"");
+				out.write(buffer.isUntitled()? "TRUE" : "FALSE");
 				out.write("\">");
+
+				// for untitled, we only have the autosave file
 				out.write(XMLUtilities.charsToEntities(buffer.getPath(), false));
+
 				out.write("</BUFFER>");
 				out.write(lineSep);
 			}
@@ -263,7 +265,7 @@ public class PerspectiveManager
 		View.ViewConfig config;
 		boolean restoreFiles;
 		boolean restoreSplits;
-		String autoReload, autoReloadDialog;
+		String autoReload, autoReloadDialog, untitled;
 
 		PerspectiveHandler(boolean restoreFiles)
 		{
@@ -311,6 +313,8 @@ public class PerspectiveManager
 				autoReload = value;
 			else if(aname.equals("AUTORELOAD_DIALOG"))
 				autoReloadDialog = value;
+			else if(aname.equals("UNTITLED"))
+				untitled = value;
 		}
 
 		/**
@@ -335,7 +339,12 @@ public class PerspectiveManager
 			{
 				if (restoreFiles && !skipRemote(charData.toString()))
 				{
-					Buffer restored = jEdit.openTemporary(null,null, charData.toString(), false);
+					boolean bufferUntitled = false;
+					if(untitled != null) {
+						bufferUntitled = "TRUE".equals(untitled);
+					}
+
+					Buffer restored = jEdit.openTemporary(null,null, charData.toString(), bufferUntitled, null, bufferUntitled);
 					// if the autoReload attributes are not present, don't set anything
 					// it's sufficient to check whether they are present on the first BUFFER element
 					if (restored != null)
@@ -344,6 +353,8 @@ public class PerspectiveManager
 							restored.setAutoReload("TRUE".equals(autoReload));
 						if(autoReloadDialog != null)
 							restored.setAutoReloadDialog("TRUE".equals(autoReloadDialog));
+						if(untitled != null)
+							 restored.setUntitled(bufferUntitled);
 						jEdit.commitTemporary(restored);
 					}
 				}
