@@ -38,10 +38,12 @@ import java.io.InputStream;
 import java.io.Reader;
 import java.lang.reflect.Modifier;
 import java.net.URL;
+import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.Enumeration;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.LinkedHashSet;
 import java.util.LinkedList;
 import java.util.List;
@@ -142,7 +144,7 @@ import static org.gjt.sp.jedit.EditBus.EBHandler;
  * @see ServiceManager
  *
  * @author Slava Pestov
- * @version $Id: PluginJAR.java 22920 2013-04-06 15:03:55Z kerik-sf $
+ * @version $Id: PluginJAR.java 24110 2015-10-19 16:23:13Z vampire0 $
  * @since jEdit 4.2pre1
  */
 public class PluginJAR
@@ -172,10 +174,16 @@ public class PluginJAR
 	private boolean activated;
 
 	// Lists of jarPaths
+	/** These plugins require this plugin */
 	private final Set<String> theseRequireMe = new LinkedHashSet<String>();
+	
 	/** The plugins that uses me as optional dependency. */
 	private final Set<String> theseUseMe = new LinkedHashSet<String>();
+	
+	/** This plugin requires these plugins. */
 	private final Set<String> weRequireThese = new LinkedHashSet<String>();
+	
+	/** These plugins are an optional dependency for me, I'll use them if they are available, no worries if they aren't. */
 	private final Set<String> weUseThese = new LinkedHashSet<String>();
 	//}}}
 
@@ -218,27 +226,128 @@ public class PluginJAR
 				load(jarPath, true);
 			}
 		}
+		
 		// Load extra jars that are part of this plugin
-		String jars = jEdit.getProperty("plugin." + className + ".jars");
-		if(jars != null)
+		Collection<String> jarsPaths = jar.getJars();
+		for(String _jarPath: jarsPaths)
 		{
-			String dir = MiscUtilities.getParentOfPath(path);
-			StringTokenizer st = new StringTokenizer(jars);
-			while(st.hasMoreTokens())
+			PluginJAR _jar = jEdit.getPluginJAR(_jarPath);
+			if(_jar == null)
 			{
-				String _jarPath = MiscUtilities.constructPath(dir,st.nextToken());
-				PluginJAR _jar = jEdit.getPluginJAR(_jarPath);
-				if(_jar == null)
-				{
-					jEdit.addPluginJAR(_jarPath);
-				}
+				jEdit.addPluginJAR(_jarPath);
 			}
 		}
 		jar.checkDependencies();
 		jar.activatePluginIfNecessary();
 		jEdit.propertiesChanged();
+		
+		// check all other installed plugins to see if any of them  
+		// use me. Reload those that do so the classloaders work together.
+		PluginJAR[] installedPlugins = jEdit.getPluginJARs();
+		for (PluginJAR installed : installedPlugins)
+		{
+			if (installed == null || installed.equals(jar) )
+			{
+				continue;	
+			}
+			EditPlugin ep = installed.getPlugin();
+			if (ep == null) 
+			{
+				continue;
+			}
+			String installedClassname = ep.getClassName();
+			PluginDepends[] deps = getPluginDepends(installedClassname);
+			for (PluginDepends dep : deps)
+			{
+				if ("plugin".equals(dep.what) && className.equals(dep.name))
+				{
+					String reloadPath = ep.getPluginJAR().getPath();
+					jEdit.removePluginJAR(ep.getPluginJAR(), false);
+					load(reloadPath, true);
+				}
+			}
+		}
 		return jar;
 	} // }}}
+	
+	//{{{ parseJarsFilesString(String path, String jarsString) method
+	/**
+	 * parse the files listed in plugin.CLASSNAME.jars or plugin.CLASSNAME.files
+	 * and return full paths to each file of the list.
+	 * @since jEdit 5.3pre1
+	 */
+	public static Collection<String> parseJarsFilesString(String path, String jarsString)
+	{
+		String dir = MiscUtilities.getParentOfPath(path);
+		StringTokenizer st = new StringTokenizer(jarsString);
+		Collection<String> jarPaths = new LinkedList<String>();
+		while(st.hasMoreTokens())
+		{
+			String _jarPath = MiscUtilities.constructPath(dir,st.nextToken());
+			jarPaths.add(_jarPath);
+		}
+		return jarPaths;
+	}
+	// }}}
+	//{{{ parseJarsFilesStringNames(String path, String jarsString) method
+	/**
+	 * parse the files listed in plugin.CLASSNAME.jars or plugin.CLASSNAME.files
+	 * and return them as a collection
+	 * @since jEdit 5.3pre1
+	 */
+	public static Collection<String> parseJarsFilesStringNames(String jarsString)
+	{
+		StringTokenizer st = new StringTokenizer(jarsString);
+		Collection<String> jarPaths = new LinkedList<String>();
+		while(st.hasMoreTokens())
+		{
+			jarPaths.add(st.nextToken());
+		}
+		return jarPaths;
+	}
+	// }}}
+
+	//{{{ getJars() method
+	/**
+	 * Get the jars listed in this plugin and return full paths to them
+	 *
+	 * @return jars full paths or empty collection if plugin is null
+	 * @since jEdit 5.3pre1
+	 */
+	public Collection<String> getJars()
+	{
+		if(plugin != null)
+		{
+			String jars = jEdit.getProperty("plugin." + plugin.getClassName() + ".jars");
+			if(jars != null)
+			{
+				return parseJarsFilesString(path, jars);
+			}
+		}
+		return Collections.emptyList();
+	}
+	// }}}
+
+	// {{{ getFiles() method
+	/**
+	 * Get the files listed in this plugin and return full paths to them
+	 *
+	 * @return files full paths or empty collection if plugin is null
+	 * @since jEdit 5.3pre1
+	 */
+	public Collection<String> getFiles()
+	{
+		if(plugin != null)
+		{
+			String files = jEdit.getProperty("plugin." + plugin.getClassName() + ".files");
+			if(files != null)
+			{
+				return parseJarsFilesString(path, files);
+			}
+		}
+		return Collections.emptyList();
+	}
+	// }}}
 
 	//{{{ getPath() method
 	/**
@@ -329,21 +438,13 @@ public class PluginJAR
 	 */
 	public static Set<String> getDependencySet(String className)
 	{
-		String dep;
 		Set<String> retval = new LinkedHashSet<String>();
-		int i=0;
-		while((dep = jEdit.getProperty("plugin." + className + ".depend." + i++)) != null)
+		PluginDepends[] deps = getPluginDepends(className);
+		for (PluginDepends pluginDepends : deps)
 		{
-			PluginDepends pluginDepends;
-			try
+			if (pluginDepends.optional)
 			{
-				pluginDepends = getPluginDepends(dep);
-			}
-			catch (IllegalArgumentException e)
-			{
-				Log.log(Log.ERROR, PluginJAR.class,
-					className + " has an invalid dependency: " + dep);
-				continue;
+				continue;	
 			}
 
 			if("plugin".equals(pluginDepends.what))
@@ -353,7 +454,7 @@ public class PluginJAR
 				{
 					Log.log(Log.ERROR, PluginJAR.class, className
 						+ " has an invalid dependency: "
-						+ dep + " (version is missing)");
+						+ pluginDepends.dep + " (version is missing)");
 					continue;
 				}
 
@@ -441,27 +542,12 @@ public class PluginJAR
 	{
 		if(plugin == null)
 			return true;
-		int i = 0;
 		boolean ok = true;
 
 		String name = plugin.getClassName();
-
-		String dep;
-		while((dep = jEdit.getProperty("plugin." + name + ".depend." + i++)) != null)
+		PluginDepends[] deps = getPluginDepends(name);
+		for (PluginDepends pluginDepends : deps)
 		{
-			PluginDepends pluginDepends;
-			try
-			{
-				pluginDepends = getPluginDepends(dep);
-			}
-			catch (IllegalArgumentException e)
-			{
-				Log.log(Log.ERROR,this,name + " has an invalid"
-					+ " dependency: " + dep);
-				ok = false;
-				continue;
-			}
-
 			if("jdk".equals(pluginDepends.what))
 			{
 				if(!pluginDepends.optional && StandardUtilities.compareStrings(
@@ -501,7 +587,7 @@ public class PluginJAR
 				{
 					Log.log(Log.ERROR,this,name
 						+ " has an invalid dependency: "
-						+ dep + " (version is missing)");
+						+ pluginDepends.dep + " (version is missing)");
 					ok = false;
 					continue;
 				}
@@ -578,39 +664,31 @@ public class PluginJAR
 			else
 			{
 				Log.log(Log.ERROR,this,name + " has unknown"
-					+ " dependency: " + dep);
+					+ " dependency: " + pluginDepends.dep);
 				ok = false;
 			}
 		}
 
 		// each JAR file listed in the plugin's jars property
 		// needs to know that we need them
-		String jars = jEdit.getProperty("plugin."
-			+ plugin.getClassName() + ".jars");
-		if(jars != null)
-		{
-			String dir = MiscUtilities.getParentOfPath(path);
+		Collection<String> jarsPaths = getJars();
 
-			StringTokenizer st = new StringTokenizer(jars);
-			while(st.hasMoreTokens())
+		for(String jarPath: jarsPaths)
+		{
+			PluginJAR jar = jEdit.getPluginJAR(jarPath);
+			if(jar == null)
 			{
-				String jarPath = MiscUtilities.constructPath(
-					dir,st.nextToken());
-				PluginJAR jar = jEdit.getPluginJAR(jarPath);
-				if(jar == null)
-				{
-					String[] args = { jarPath };
-					jEdit.pluginError(path, "plugin-error.missing-jar",args);
-					ok = false;
-				}
-				else
-				{
-					weRequireThese.add(jarPath);
-					jar.theseRequireMe.add(path);
-				}
+				String[] args = { jarPath };
+				jEdit.pluginError(path, "plugin-error.missing-jar",args);
+				ok = false;
+			}
+			else
+			{
+				weRequireThese.add(jarPath);
+				jar.theseRequireMe.add(path);
 			}
 		}
-
+		
 		if(!ok)
 			breakPlugin();
 
@@ -630,38 +708,105 @@ public class PluginJAR
 	} //}}}
 
 	//{{{ getPluginDepends() method
-	private static PluginDepends getPluginDepends(String dep) throws IllegalArgumentException
+	private static PluginDepends[] getPluginDepends(String classname) throws IllegalArgumentException
 	{
-		boolean optional;
-		if(dep.startsWith("optional "))
+		List<PluginDepends> ret = new ArrayList<PluginDepends>();
+		int i = 0;
+		String dep;
+		while((dep = jEdit.getProperty("plugin." + classname + ".depend." + i++)) != null)
 		{
-			optional = true;
-			dep = dep.substring("optional ".length());
+			boolean optional;
+			if(dep.startsWith("optional "))
+			{
+				optional = true;
+				dep = dep.substring("optional ".length());
+			}
+			else
+			{
+				optional = false;
+			}
+	
+			int index = dep.indexOf(' ');
+			if(index == -1)
+				throw new IllegalArgumentException("wrong dependency");
+	
+			String what = dep.substring(0,index);
+			String arg = dep.substring(index + 1);
+			PluginDepends depends = new PluginDepends();
+			depends.what = what;
+			depends.arg = arg;
+			depends.optional = optional;
+			depends.dep = dep;
+			if ("plugin".equals(what))
+				depends.name = arg.indexOf(' ') > 0 ? arg.substring(0, arg.indexOf(' ')) : arg;
+			ret.add(depends);
 		}
-		else
+		return ret.toArray(new PluginDepends[ret.size()]);
+	} //}}}
+
+	//{{{ getDependencies() method
+	/**
+	 * Returns a list of dependencies by searching the plugin properties.
+	 * @param classname The classname of a plugin
+	 * @return A list of classnames of plugins the plugin depends on.
+	 */
+	public static Set<String> getDependencies(String classname) throws IllegalArgumentException
+	{
+		Set<String> ret = new HashSet<String>();
+		int i = 0;
+		String dep;
+		while((dep = jEdit.getProperty("plugin." + classname + ".depend." + i++)) != null)
 		{
-			optional = false;
+			int index = dep.indexOf(' ');
+			String what = dep.substring(0,index);
+			String arg = dep.substring(index + 1);
+			if ("plugin".equals(what))
+			{
+				ret.add(arg.indexOf(' ') > 0 ? arg.substring(0, arg.indexOf(' ')) : arg);
+			}
 		}
+		return ret;
+	} //}}}
 
-		int index = dep.indexOf(' ');
-		if(index == -1)
-			throw new IllegalArgumentException("wrong dependency");
-
-		String what = dep.substring(0,index);
-		String arg = dep.substring(index + 1);
-		PluginDepends depends = new PluginDepends();
-		depends.what = what;
-		depends.arg = arg;
-		depends.optional = optional;
-		return depends;
+	//{{{ getOptionalDependencies() method
+	/**
+	 * Returns a list of optional dependencies by searching the plugin properties.
+	 * @param classname The classname of a plugin
+	 * @return A list of classnames of plugins the plugin optionally depends on.
+	 */
+	public static Set<String> getOptionalDependencies(String classname) throws IllegalArgumentException
+	{
+		Set<String> ret = new HashSet<String>();
+		int i = 0;
+		String dep;
+		while((dep = jEdit.getProperty("plugin." + classname + ".depend." + i++)) != null)
+		{
+			int index = dep.indexOf(' ');
+			String what = dep.substring(0,index);
+			String arg = dep.substring(index + 1);
+			if ("optional".equals(what))
+			{
+				index = arg.indexOf(' ');
+				what = arg.substring(0, index);
+				arg = arg.substring(index + 1);
+				if ("plugin".equals(what))
+				{
+					ret.add(arg.indexOf(' ') > 0 ? arg.substring(0, arg.indexOf(' ')) : arg);
+				}
+			}
+		}
+		return ret;
 	} //}}}
 
 	//{{{ PluginDepends class
 	private static class PluginDepends
 	{
-		String what;
-		String arg;
+		String dep;		// full string, e.g. plugin errorlist.ErrorList 1.3
+		String what;	// depends type, e.g. jedit, jdk, plugin
+		String arg;		// classname + version, e.g errorlist.ErrorList 1.3
+		String name;	// just the class name, e.g. errorlist.ErrorList, only filled in if what is plugin
 		boolean optional;
+		
 	} //}}}
 
 	//{{{ transitiveClosure()
@@ -676,33 +821,56 @@ public class PluginJAR
 	 */
 	public static void transitiveClosure(String[] dependents, List<String> listModel)
 	{
-  		for(int i = 0; i < dependents.length; i++)
-  		{
-  			String jarPath = dependents[i];
-  			if(!listModel.contains(jarPath))
-  			{
-  				listModel.add(jarPath);
-  				PluginJAR jar = jEdit.getPluginJAR(
-  					jarPath);
+		for (String jarPath : dependents)
+		{
+			if (!listModel.contains(jarPath))
+			{
+				listModel.add(jarPath);
+				PluginJAR jar = jEdit.getPluginJAR(jarPath);
 				if (jar == null)
 				{
 					Log.log(Log.WARNING, PluginJAR.class, "The jar file " + jarPath +
-						" doesn't exist, the plugin may have been partially removed");
+									      " doesn't exist, the plugin may have been partially removed");
 				}
 				else
 				{
-					transitiveClosure(jar.getDependentPlugins(),
-									  listModel);
+					transitiveClosure(jar.getDependentPlugins(), listModel);
 				}
-  			}
-  		}
+			}
+		}
   	} //}}}
 
 	//{{{ getDependentPlugins() method
-	  public String[] getDependentPlugins()
-	  {
-		  return theseRequireMe.toArray(new String[theseRequireMe.size()]);
-	  } //}}}
+	/**
+	* @return an array of plugin names that have a hard dependency on this plugin
+	*/
+	public String[] getDependentPlugins()
+	{
+		return theseRequireMe.toArray(new String[theseRequireMe.size()]);
+	} //}}}
+
+	//{{{ getOptionallyDependentPlugins() method
+	/**
+	* @return an array of plugin names that have an optional dependency on this plugin
+	*/
+	public String[] getOptionallyDependentPlugins()
+	{
+		return theseUseMe.toArray(new String[theseUseMe.size()]);
+	} //}}}
+	
+	//{{{ getAllDependentPlugins() method
+	/**
+	* @return an array of plugin names that have a dependency or an optional dependency on this plugin,
+	* this returns a combination of <code>getDependentPlugins</code> and <code>getOptionallyDependentPlugins</code>.
+	*/
+	public String[] getAllDependentPlugins()
+	{
+		String[] dependents = new String[theseRequireMe.size() + theseUseMe.size()];
+		System.arraycopy( theseRequireMe.toArray(), 0, dependents, 0, theseRequireMe.size() );
+		System.arraycopy( theseUseMe.toArray(), 0, dependents, theseRequireMe.size(), theseUseMe.size());
+		return dependents;
+	} //}}}
+	
 
 	//{{{ getPlugin() method
 	/**
@@ -877,8 +1045,7 @@ public class PluginJAR
 			Buffer buffer = jEdit.getFirstBuffer();
 			while(buffer != null)
 			{
-				if(buffer.getFoldHandler() != null
-					&& buffer.getFoldHandler().getClass()
+				if(buffer.getFoldHandler().getClass()
 					.getClassLoader() == classLoader)
 				{
 					buffer.setFoldHandler(
@@ -965,7 +1132,7 @@ public class PluginJAR
 	//{{{ Package-private members
 
 	//{{{ Static methods
-
+	
 	//{{{ getPluginCache() method
 	public static PluginCacheEntry getPluginCache(PluginJAR plugin)
 	{
@@ -1031,6 +1198,43 @@ public class PluginJAR
 		}
 	} //}}}
 
+	//{{{ getPluginCacheEntry() method
+	/**
+	 * Returns the cache entry for an installed but not loaded plugin.
+	 * There is no need to use this method if the plugin is loaded.
+	 *
+	 * @param path path to the the plugin jar
+	 * @return cache entry or null
+	 * @throws IOException if jEdit cannot generate cache
+	 * @since jEdit 5.3pre1
+	 */
+	public static PluginJAR.PluginCacheEntry getPluginCacheEntry(String path) throws IOException
+	{
+		PluginJAR pluginJAR = new PluginJAR(new File(path));
+		PluginJAR.PluginCacheEntry pluginCacheEntry = PluginJAR.getPluginCache(pluginJAR);
+		if (pluginCacheEntry == null)
+		{
+			try
+			{
+				pluginCacheEntry = pluginJAR.generateCache();
+			}
+			finally
+			{
+				IOUtilities.closeQuietly(pluginJAR.getZipFile());
+			}
+		}
+		if(pluginCacheEntry == null)
+		{
+			// this happens when, for some reason, two versions
+			// of a plugin are installed, e.g when XSLT.jar and
+			// xslt.jar are both in $JEDIT_HOME/jars on Linux.
+			Log.log(Log.WARNING, PluginJAR.class,
+					"couldn't load plugin "+pluginJAR.getPath()
+					+" (most likely other version exists)");
+		}
+		return pluginCacheEntry;
+	}//}}}
+
 	//}}}
 
 	//{{{ PluginJAR constructor
@@ -1053,7 +1257,7 @@ public class PluginJAR
 	} //}}}
 
 	//{{{ init() method
-	boolean init()
+	public boolean init()
 	{
 		PluginCacheEntry cache = getPluginCache(this);
 		if(cache != null)
@@ -1093,7 +1297,7 @@ public class PluginJAR
 	} //}}}
 
 	//{{{ uninit() method
-	void uninit(boolean exit)
+	public void uninit(boolean exit)
 	{
 		deactivatePlugin(exit);
 
@@ -1571,9 +1775,7 @@ public class PluginJAR
 				FoldHandler.getFoldHandler(
 				buffer.getStringProperty("folding"));
 			// == null before loaded
-			if(buffer.getFoldHandler() != null
-				&& handler != null
-				&& handler != buffer.getFoldHandler())
+			if(handler != null && handler != buffer.getFoldHandler())
 			{
 				buffer.setFoldHandler(handler);
 			}
@@ -1742,10 +1944,10 @@ public class PluginJAR
 			else
 			{
 				dout.writeInt(cachedServices.length);
-				for(int i = 0; i < cachedServices.length; i++)
+				for (ServiceManager.Descriptor cachedService : cachedServices)
 				{
-					writeString(dout,cachedServices[i].clazz);
-					writeString(dout,cachedServices[i].name);
+					writeString(dout, cachedService.clazz);
+					writeString(dout, cachedService.name);
 				}
 			}
 
@@ -1878,10 +2080,8 @@ public class PluginJAR
 			else
 			{
 				dout.writeInt(str.length);
-				for(int i = 0; i < str.length; i++)
-				{
-					writeString(dout,str[i]);
-				}
+				for (String s : str)
+					writeString(dout, s);
 			}
 		} //}}}
 
@@ -1896,10 +2096,8 @@ public class PluginJAR
 			else
 			{
 				dout.writeInt(bools.length);
-				for(int i = 0; i < bools.length; i++)
-				{
-					dout.writeBoolean(bools[i]);
-				}
+				for (boolean bool : bools)
+					dout.writeBoolean(bool);
 			}
 		} //}}}
 
