@@ -38,11 +38,14 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
-import java.util.HashSet;
+import java.util.Comparator;
+import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Set;
 import java.util.Stack;
 
+import java.util.TreeSet;
+
 import javax.annotation.Nonnull;
 import javax.annotation.Nullable;
 import javax.swing.JComponent;
@@ -88,6 +91,7 @@ import org.gjt.sp.jedit.textarea.ScrollListener;
 import org.gjt.sp.jedit.textarea.TextArea;
 import org.gjt.sp.jedit.visitors.JEditVisitor;
 import org.gjt.sp.jedit.visitors.JEditVisitorAdapter;
+import org.gjt.sp.util.GenericGUIUtilities;
 import org.gjt.sp.util.Log;
 import org.gjt.sp.util.StandardUtilities;
 //}}}
@@ -131,7 +135,7 @@ import org.gjt.sp.util.StandardUtilities;
  *
  * @author Slava Pestov
  * @author John Gellene (API documentation)
- * @version $Id: View.java 22815 2013-02-27 19:23:28Z ezust $
+ * @version $Id: View.java 24814 2018-01-10 03:51:43Z ezust $
  */
 public class View extends JFrame implements InputHandlerProvider
 {
@@ -279,7 +283,7 @@ public class View extends JFrame implements InputHandlerProvider
 			if (dockingFrameworkProvider == null)
 			{
 				Log.log(Log.ERROR, View.class, "No docking framework " + framework +
-							       " available, using the original one");
+								   " available, using the original one");
 				dockingFrameworkProvider = (DockingFrameworkProvider)
 				ServiceManager.getService(
 					DOCKING_FRAMEWORK_PROVIDER_SERVICE, ORIGINAL_DOCKING_FRAMEWORK);
@@ -774,7 +778,7 @@ public class View extends JFrame implements InputHandlerProvider
 			editPane.focusOnTextArea();
 		}
 		else
-			getToolkit().beep();
+			javax.swing.UIManager.getLookAndFeel().provideErrorFeedback(null);
 	} //}}}
 
 	//{{{ unsplitCurrent() method
@@ -802,7 +806,7 @@ public class View extends JFrame implements InputHandlerProvider
 			// of the current edit pane's parent splitter
 			for(EditPane _editPane: getEditPanes())
 			{
-				if(GUIUtilities.isAncestorOf(comp,_editPane)
+				if(GenericGUIUtilities.isAncestorOf(comp,_editPane)
 					&& _editPane != editPane)
 				{
 					if (scope == BufferSet.Scope.editpane)
@@ -835,7 +839,7 @@ public class View extends JFrame implements InputHandlerProvider
 			editPane.focusOnTextArea();
 		}
 		else
-			getToolkit().beep();
+			javax.swing.UIManager.getLookAndFeel().provideErrorFeedback(null);
 	} //}}}
 
 	//{{{ resplit() method
@@ -847,7 +851,7 @@ public class View extends JFrame implements InputHandlerProvider
 	public void resplit()
 	{
 		if(lastSplitConfig == null)
-			getToolkit().beep();
+			javax.swing.UIManager.getLookAndFeel().provideErrorFeedback(null);
 		else
 			setSplitConfig(null,lastSplitConfig);
 	} //}}}
@@ -963,16 +967,25 @@ public class View extends JFrame implements InputHandlerProvider
 
 	//{{{ getBuffers() method
 	/**
-	 * Returns all Buffers opened in this View.
+	 * Returns all Buffers opened in this View,
+	 * Sorted according to View options. (as of jEdit 5.2)
+	 * With order preserved for unsorted buffersets (as of jEdit 5.3)
 	 * @since jEdit 5.1
 	 */
 	public Buffer[] getBuffers()
 	{
 		BufferSetManager mgr = jEdit.getBufferSetManager();
-		Collection<Buffer> retval = new HashSet<Buffer>();
+		Collection<Buffer> retval = null;
 		for (EditPane ep: getEditPanes())
 		{
 			BufferSet bs = ep.getBufferSet();
+			if (retval == null) {
+				Comparator<Buffer> sorter = bs.getSorter();
+				if (sorter == null)
+					retval = new LinkedHashSet<Buffer>();
+				else
+					retval = new TreeSet<Buffer>(sorter);
+			}
 			Collections.addAll(retval, bs.getAllBuffers());
 			// If scope is not editpane, then all buffersets
 			// are the same and we got what we need.
@@ -1211,10 +1224,10 @@ public class View extends JFrame implements InputHandlerProvider
 	{
 		List<Buffer> buffers = new ArrayList<Buffer>();
 		EditPane[] editPanes = getEditPanes();
-		for(int i = 0; i < editPanes.length; i++)
+		for (EditPane ep : editPanes)
 		{
-			Buffer buffer = editPanes[i].getBuffer();
-			if(!buffers.contains(buffer))
+			Buffer buffer = ep.getBuffer();
+			if (!buffers.contains(buffer))
 				buffers.add(buffer);
 		}
 
@@ -1289,9 +1302,8 @@ public class View extends JFrame implements InputHandlerProvider
 	public void visit(JEditVisitor visitor)
 	{
 		EditPane[] panes = getEditPanes();
-		for (int i = 0; i < panes.length; i++)
+		for (EditPane editPane : panes)
 		{
-			EditPane editPane = panes[i];
 			visitor.visit(editPane);
 			visitor.visit(editPane.getTextArea());
 		}
@@ -1299,7 +1311,7 @@ public class View extends JFrame implements InputHandlerProvider
 
 	// {{{ closeAllMenus()
 	/** closes any popup menus that may have been opened
-	    @since jEdit 4.4pre1
+		@since jEdit 4.4pre1
 	*/
 	public void closeAllMenus()
 	{
@@ -1399,11 +1411,11 @@ public class View extends JFrame implements InputHandlerProvider
 	} //}}}
 
 	//{{{ isFullScreenMode method
-	public boolean isFullScreenMode() 
+	public boolean isFullScreenMode()
 	{
 		return fullScreenMode;
 	}//}}}
-	
+
 	//{{{ toggleFullScreen() method
 	public void toggleFullScreen()
 	{
@@ -1442,6 +1454,7 @@ public class View extends JFrame implements InputHandlerProvider
 		closeAllMenus();
 		// so you can keep typing in your editpane afterwards...
 		editPane.getTextArea().requestFocus();
+		EditBus.send(new ViewUpdate(this,ViewUpdate.FULL_SCREEN_TOGGLED));
 	} //}}}
 
 	//{{{ confirmToCloseDirty() methods
@@ -1454,6 +1467,8 @@ public class View extends JFrame implements InputHandlerProvider
 	 */
 	boolean confirmToCloseDirty()
 	{
+		boolean autosaveUntitled = jEdit.getBooleanProperty("autosaveUntitled");
+		boolean suppressNotSavedConfirmUntitled = jEdit.getBooleanProperty("suppressNotSavedConfirmUntitled") || autosaveUntitled;
 		Set<Buffer> checkingBuffers = getOpenBuffers();
 		for (View view: jEdit.getViews())
 		{
@@ -1465,7 +1480,7 @@ public class View extends JFrame implements InputHandlerProvider
 		}
 		for (Buffer buffer: checkingBuffers)
 		{
-			if (buffer.isDirty())
+			if (buffer.isDirty() && !(buffer.isUntitled() && suppressNotSavedConfirmUntitled))
 			{
 				return new CloseDialog(this, checkingBuffers).isOK();
 			}
@@ -1486,8 +1501,8 @@ public class View extends JFrame implements InputHandlerProvider
 		dispose();
 
 		EditPane[] editPanes = getEditPanes();
-		for(int i = 0; i < editPanes.length; i++)
-			editPanes[i].close();
+		for (EditPane ep : editPanes)
+			ep.close();
 
 		// null some variables so that retaining references
 		// to closed views won't hurt as much.
@@ -1606,10 +1621,9 @@ public class View extends JFrame implements InputHandlerProvider
 		}
 
 		EditPane[] editPanes = getEditPanes();
-		for(int i = 0; i < editPanes.length; i++)
+		for (EditPane ep : editPanes)
 		{
-			EditPane ep = editPanes[i];
-			if(ep.getBuffer() == buffer
+			if (ep.getBuffer() == buffer
 				/* ignore zero-height splits, etc */
 				&& ep.getTextArea().getVisibleLines() > 1)
 			{
@@ -1663,21 +1677,22 @@ public class View extends JFrame implements InputHandlerProvider
 		}
 		else
 		{
+			boolean autosaveUntitled = jEdit.getBooleanProperty("autosaveUntitled");
+
 			// the component is an editPane
 			EditPane editPane = (EditPane) component;
 			splitConfig.append('"');
-			splitConfig.append(StandardUtilities.charsToEscapes(
-				editPane.getBuffer().getPath()));
+			Buffer editPaneBuffer = editPane.getBuffer();
+			splitConfig.append(StandardUtilities.charsToEscapes(editPaneBuffer.getPath()));
 			splitConfig.append("\" buffer");
 			BufferSet bufferSet = editPane.getBufferSet();
 			Buffer[] buffers = bufferSet.getAllBuffers();
 			for (Buffer buffer : buffers)
 			{
-				if (!buffer.isNewFile())
+				if (!buffer.isNewFile() || (buffer.isUntitled() && autosaveUntitled))
 				{
 					splitConfig.append(" \"");
-					splitConfig.append(StandardUtilities.charsToEscapes(
-						buffer.getPath()));
+					splitConfig.append(StandardUtilities.charsToEscapes(buffer.getPath() ));
 					splitConfig.append("\" buff");
 				}
 			}
@@ -1775,7 +1790,7 @@ loop:		while (true)
 						if (buffer == null)
 						{
 							buffer = jEdit.openTemporary(jEdit.getActiveView(), null,
-											    path, true, null);
+												path, true, null, true);
 							jEdit.commitTemporary(buffer);
 						}
 					}
@@ -1849,13 +1864,16 @@ loop:		while (true)
 		for (int i = 0; i < mbar.getMenuCount(); i++)
 		{
 			JMenu menu = mbar.getMenu(i);
-			int mnemonic = menu.getMnemonic();
-			if (mnemonic != 0)
+			if (menu != null)
 			{
-				Object keyBinding = inputHandler.getKeyBinding("A+" + Character.toLowerCase((char) mnemonic));
-				if (keyBinding != null)
+				int mnemonic = menu.getMnemonic();
+				if (mnemonic != 0)
 				{
-					menu.setMnemonic(0);
+					Object keyBinding = inputHandler.getKeyBinding("A+" + Character.toLowerCase((char) mnemonic));
+					if (keyBinding != null)
+					{
+						menu.setMnemonic(0);
+					}
 				}
 			}
 		}
@@ -1873,7 +1891,7 @@ loop:		while (true)
 		getContentPane().remove(status);
 
 		boolean showStatus = plainView ? jEdit.getBooleanProperty("view.status.plainview.visible") :
-				    jEdit.getBooleanProperty("view.status.visible");
+					jEdit.getBooleanProperty("view.status.visible");
 		if (jEdit.getBooleanProperty("view.toolbar.alternateLayout"))
 		{
 			getContentPane().add(BorderLayout.NORTH,topToolBars);
@@ -2025,9 +2043,9 @@ loop:		while (true)
 			|| msg.getWhat() == BufferUpdate.LOADED)
 		{
 			EditPane[] editPanes = getEditPanes();
-			for(int i = 0; i < editPanes.length; i++)
+			for (EditPane ep : editPanes)
 			{
-				if(editPanes[i].getBuffer() == buffer)
+				if (ep.getBuffer() == buffer)
 				{
 					updateTitle();
 					break;
@@ -2062,7 +2080,9 @@ loop:		while (true)
 		final int check = jEdit.getIntegerProperty("checkFileStatus");
 		if ((check == 0) || !jEdit.isStartupDone()) return;
 		// "buffer visit" also includes checking the buffer when you change editpanes.
-		if ((msg.getWhat() == ViewUpdate.EDIT_PANE_CHANGED) &&
+		// "buffer visit" also includes checking the buffer when you activate view, coming from
+		// another program, which could have alterered file on disk.
+		if ((msg.getWhat() == ViewUpdate.EDIT_PANE_CHANGED || msg.getWhat() == ViewUpdate.ACTIVATED) &&
 			((check & GeneralOptionPane.checkFileStatus_focusBuffer) > 0))
 			jEdit.checkBufferStatus(View.this, true);
 		else if ((msg.getWhat() == ViewUpdate.ACTIVATED) &&
@@ -2112,14 +2132,14 @@ loop:		while (true)
 	private void updateGutterBorders()
 	{
 		EditPane[] editPanes = getEditPanes();
-		for(int i = 0; i < editPanes.length; i++)
-			editPanes[i].getTextArea().getGutter().updateBorder();
+		for (EditPane editPane : editPanes)
+			editPane.getTextArea().getGutter().updateBorder();
 	} //}}}
 
 	//{{{ getOpenBuffers() method
 	private Set<Buffer> getOpenBuffers()
 	{
-		Set<Buffer> openBuffers = new HashSet<Buffer>();
+		Set<Buffer> openBuffers = new LinkedHashSet<Buffer>();
 		for (EditPane editPane: getEditPanes())
 		{
 			openBuffers.addAll(Arrays.asList(
@@ -2268,7 +2288,7 @@ loop:		while (true)
 	{
 		Rectangle bounds;
 		if (parent == null)
-			bounds = GUIUtilities.getScreenBounds();
+			bounds = GenericGUIUtilities.getScreenBounds();
 		else
 			bounds = parent.getGraphicsConfiguration().getBounds();
 		int minWidth = jEdit.getIntegerProperty("view.minStartupWidth");
