@@ -349,16 +349,19 @@ public class BufferSetManager
 		}
 		if (parent == null)
 		{
-			parent = System.getProperty("user.home");
+			parent = MiscUtilities.getBackupDirectory();
 		}
-		VFS vfs = VFSManager.getVFSForPath(parent);
-		if ((vfs.getCapabilities() & VFS.WRITE_CAP) == 0)
+		VFS vfs = null;
+		if (parent != null) {
+			vfs = VFSManager.getVFSForPath(parent);
+		}
+		if (vfs != null && (vfs.getCapabilities() & VFS.WRITE_CAP) == 0)
 		{
 			// cannot write on that VFS, creating untitled buffer in home directory
 			parent = System.getProperty("user.home");
 		}
 		Buffer newEmptyBuffer = jEdit.openTemporary(view, parent,
-							    "Untitled-" + untitledCount,true, null);
+							    "Untitled-" + untitledCount,true, true);
 		jEdit.commitTemporary(newEmptyBuffer);
 		return newEmptyBuffer;
 	} //}}}
