@@ -33,6 +33,7 @@ import java.util.*;
 import java.util.List;
 
 import org.gjt.sp.jedit.*;
+import org.gjt.sp.util.GenericGUIUtilities;
 import org.gjt.sp.util.Log;
 //}}}
 /** "About jEdit" dialog
@@ -44,22 +45,16 @@ public class AboutDialog extends JDialog implements ActionListener
 	{
 		super(view,jEdit.getProperty("about.title"), true);
 		setResizable(false);
+
+		JPanel p = new JPanel(new BorderLayout());
+		p.setBorder(BorderFactory.createEmptyBorder(12, 12, 11, 11));
+			
+		final AboutPanel aboutPanel = new AboutPanel();
+		p.add(aboutPanel);
+		
 		JButton closeBtn = new JButton(jEdit.getProperty("common.close"));
 		closeBtn.addActionListener(this);
 		getRootPane().setDefaultButton(closeBtn);
-
-		JPanel p = new JPanel(new BorderLayout());
-		final AboutPanel aboutPanel = new AboutPanel();
-		JPanel flowP = new JPanel(new FlowLayout());
-		flowP.add(closeBtn);
-		flowP.add(Box.createRigidArea(new Dimension(40, 40)));
-		Dimension dim = new Dimension(10, 0);
-		p.add(BorderLayout.WEST, Box.createRigidArea(dim));
-		p.add(BorderLayout.EAST, Box.createRigidArea(dim));
-		p.add(BorderLayout.NORTH, Box.createRigidArea(new Dimension(10, 10)));
-		p.add(BorderLayout.SOUTH, flowP);
-		p.add(BorderLayout.CENTER, aboutPanel);
-
 		closeBtn.setToolTipText(jEdit.getProperty("about.navigate"));
 		closeBtn.addKeyListener(new KeyAdapter()
 		{
@@ -69,6 +64,13 @@ public class AboutDialog extends JDialog implements ActionListener
 			}
 		});
 
+		JPanel buttonPanel = new JPanel();
+		buttonPanel.setLayout(new BoxLayout(buttonPanel, BoxLayout.X_AXIS));
+		buttonPanel.setBorder(BorderFactory.createEmptyBorder(17, 0, 0, 0));
+		buttonPanel.add(Box.createGlue());
+		buttonPanel.add(closeBtn);
+		p.add(buttonPanel, BorderLayout.SOUTH);
+
 		setContentPane(p);
 		pack();
 		setLocationRelativeTo(jEdit.getActiveView());
@@ -194,7 +196,7 @@ public class AboutDialog extends JDialog implements ActionListener
 			else if ((e.getKeyCode()) == KeyEvent.VK_ESCAPE)
 			{
 				e.consume();
-				JDialog d = GUIUtilities.getParentDialog(this);
+				JDialog d = GenericGUIUtilities.getParentDialog(this);
 				stopThread();
 				d.dispose();
 			}
