@@ -30,10 +30,6 @@ import javax.swing.*;
 import java.awt.*;
 import java.awt.event.*;
 
-import java.util.Arrays;
-
-import org.gjt.sp.jedit.buffer.FoldHandler;
-import org.gjt.sp.jedit.buffer.JEditBuffer;
 import org.gjt.sp.jedit.options.BufferOptionPane;
 
 import org.gjt.sp.jedit.*;
@@ -42,7 +38,7 @@ import org.gjt.sp.jedit.*;
 
 /** Buffer-specific options dialog.
  * @author Slava Pestov
- * @version $Id: BufferOptions.java 21831 2012-06-18 22:54:17Z ezust $
+ * @version $Id: BufferOptions.java 24251 2015-12-23 00:49:59Z daleanson $
  *
  */
 
@@ -53,8 +49,6 @@ public class BufferOptions extends EnhancedDialog
 	public BufferOptions(View view, Buffer buffer)
 	{
 		super(view,jEdit.getProperty("buffer-options.title"),true);
-		this.view = view;
-		this.buffer = buffer;
 
 		JPanel content = new JPanel(new BorderLayout());
 		content.setBorder(new EmptyBorder(12,12,12,12));
@@ -71,19 +65,20 @@ public class BufferOptions extends EnhancedDialog
 		buttons.setLayout(new BoxLayout(buttons,BoxLayout.X_AXIS));
 		buttons.setBorder(new EmptyBorder(12,0,0,0));
 		buttons.add(Box.createGlue());
-
+		
 		ok = new JButton(jEdit.getProperty("common.ok"));
 		ok.addActionListener(actionListener);
 		getRootPane().setDefaultButton(ok);
-		buttons.add(ok);
-
-		buttons.add(Box.createHorizontalStrut(6));
 
 		cancel = new JButton(jEdit.getProperty("common.cancel"));
 		cancel.addActionListener(actionListener);
+		ok.setPreferredSize(cancel.getPreferredSize());
+		
+		buttons.add(ok);
+		buttons.add(Box.createHorizontalStrut(6));
 		buttons.add(cancel);
-
-		buttons.add(Box.createGlue());
+		
+		//buttons.add(Box.createGlue());
 		content.add(BorderLayout.SOUTH,buttons);
 
 		//}}}
@@ -112,8 +107,6 @@ public class BufferOptions extends EnhancedDialog
 
 	//{{{ Private members
 
-	private View view;
-	private Buffer buffer;
 	private BufferOptionPane panel;
 	private JButton ok;
 	private JButton cancel;
