@@ -24,9 +24,8 @@ package org.gjt.sp.jedit.gui;
 
 //{{{ Imports
 import javax.swing.*;
-import java.awt.event.*;
-import java.awt.*;
 import org.gjt.sp.jedit.*;
+import org.gjt.sp.jedit.gui.statusbar.HoverSetStatusMouseHandler;
 //}}}
 /** A toolbar button */
 public class EnhancedButton extends RolloverButton
@@ -37,8 +36,6 @@ public class EnhancedButton extends RolloverButton
 	{
 		super(icon);
 
-		this.action = action;
-
 		if(action != null)
 		{
 			// set the name of this button :
@@ -57,7 +54,7 @@ public class EnhancedButton extends RolloverButton
 
 			setEnabled(true);
 			addActionListener(new EditAction.Wrapper(context,action));
-			addMouseListener(new MouseHandler());
+			addMouseListener(new HoverSetStatusMouseHandler(action));
 		}
 		else
 			setEnabled(false);
@@ -65,50 +62,13 @@ public class EnhancedButton extends RolloverButton
 		setToolTipText(toolTip);
 	} //}}}
 
-	//{{{ isFocusTraversable() method
-	public boolean isFocusTraversable()
+	//{{{ isFocusable() method
+	public boolean isFocusable()
 	{
 		return false;
 	} //}}}
 
 	//{{{ Private members
-	private String action;
 	//}}}
 
-	//{{{ MouseHandler class
-	class MouseHandler extends MouseAdapter
-	{
-		boolean msgSet = false;
-
-		public void mouseReleased(MouseEvent evt)
-		{
-			if(msgSet)
-			{
-				GUIUtilities.getView((Component)evt.getSource())
-					.getStatus().setMessage(null);
-				msgSet = false;
-			}
-		}
-
-		public void mouseEntered(MouseEvent evt)
-		{
-			String msg = jEdit.getProperty(action + ".mouse-over");
-			if(msg != null)
-			{
-				GUIUtilities.getView((Component)evt.getSource())
-					.getStatus().setMessage(msg);
-				msgSet = true;
-			}
-		}
-
-		public void mouseExited(MouseEvent evt)
-		{
-			if(msgSet)
-			{
-				GUIUtilities.getView((Component)evt.getSource())
-					.getStatus().setMessage(null);
-				msgSet = false;
-			}
-		}
-	} //}}}
 }
