@@ -39,10 +39,10 @@ import java.util.*;
  *
  * @author Slava Pestov
  * @author Eric Le Lay
- * @version $Id: HistoryModel.java 21831 2012-06-18 22:54:17Z ezust $
+ * @version $Id: HistoryModel.java 24427 2016-06-22 22:29:03Z daleanson $
  */
-public class HistoryModel extends DefaultListModel
-	implements MutableListModel
+public class HistoryModel extends DefaultListModel<String>
+	implements MutableListModel<String>
 {
 	//{{{ HistoryModel constructor
 	/**
@@ -99,7 +99,7 @@ public class HistoryModel extends DefaultListModel
 
 	//{{{ insertElementAt() method
 	@Override
-	public void insertElementAt(Object obj, int index)
+	public void insertElementAt(String obj, int index)
 	{
 		modified = true;
 		super.insertElementAt(obj,index);
@@ -116,7 +116,6 @@ public class HistoryModel extends DefaultListModel
 	} //}}}
 
 	//{{{ removeElement() method
-	@Override
 	public boolean removeElement(Object obj)
 	{
 		modified = true;
