@@ -30,6 +30,7 @@ import org.gjt.sp.jedit.textarea.JEditTextArea;
 import org.gjt.sp.jedit.*;
 import org.gjt.sp.jedit.buffer.JEditBuffer;
 import org.gjt.sp.jedit.input.AbstractInputHandler;
+import org.gjt.sp.util.GenericGUIUtilities;
 import org.gjt.sp.util.Log;
 import org.gjt.sp.util.StandardUtilities;
 
@@ -46,7 +47,7 @@ import java.awt.*;
  * to the implementations of this class to do so.
  *
  * @author Slava Pestov
- * @version $Id: InputHandler.java 21831 2012-06-18 22:54:17Z ezust $
+ * @version $Id: InputHandler.java 24411 2016-06-19 11:02:53Z kerik-sf $
  * @see org.gjt.sp.jedit.gui.DefaultInputHandler
  */
 public abstract class InputHandler extends AbstractInputHandler<EditAction>
@@ -349,7 +350,7 @@ public abstract class InputHandler extends AbstractInputHandler<EditAction>
 				if(label == null)
 					label = action.getName();
 				else
-					label = GUIUtilities.prettifyMenuLabel(label);
+					label = GenericGUIUtilities.prettifyMenuLabel(label);
 
 				Object[] pp = { label, _repeatCount };
 
@@ -400,7 +401,7 @@ public abstract class InputHandler extends AbstractInputHandler<EditAction>
 	public void invokeLastAction()
 	{
 		if(lastAction == null)
-			view.getToolkit().beep();
+			javax.swing.UIManager.getLookAndFeel().provideErrorFeedback(null); 
 		else
 			invokeAction(lastAction);
 	} //}}}
