@@ -27,17 +27,18 @@ import java.awt.event.*;
 import javax.swing.KeyStroke;
 import java.util.HashMap;
 import java.util.Map;
+import java.util.Objects;
+
 import org.gjt.sp.jedit.Debug;
 import org.gjt.sp.jedit.OperatingSystem;
 import org.gjt.sp.util.Log;
-import org.gjt.sp.util.StandardUtilities;
 //}}}
 
 /** In conjunction with the <code>KeyEventWorkaround</code>, hides some
  * warts in the AWT key event API.
  *
  * @author Slava Pestov
- * @version $Id: KeyEventTranslator.java 21831 2012-06-18 22:54:17Z ezust $
+ * @version $Id: KeyEventTranslator.java 23981 2015-08-10 14:56:24Z daleanson $
  */
 public class KeyEventTranslator
 {
@@ -79,15 +80,7 @@ public class KeyEventTranslator
 				|| (keyCode >= KeyEvent.VK_A
 				&& keyCode <= KeyEvent.VK_Z))
 			{
-				if(Debug.ALTERNATIVE_DISPATCHER)
-					return null;
-				else
-				{
-					returnValue = new Key(
-						modifiersToString(modifiers),
-						'\0',Character.toLowerCase(
-						(char)keyCode));
-				}
+				returnValue = new Key(modifiersToString(modifiers), '\0', Character.toLowerCase((char)keyCode));			
 			}
 			else
 			{
@@ -108,14 +101,8 @@ public class KeyEventTranslator
 					// do a "<space> to insert ".
 					if((modifiers & ~InputEvent.SHIFT_MASK) == 0)
 						returnValue = null;
-                    else if (Debug.ALTERNATIVE_DISPATCHER && (modifiers & ~InputEvent.META_MASK) == 0)
-                        returnValue = null;
-					else
-					{
-						returnValue = new Key(
-							modifiersToString(modifiers),
-							0,' ');
-					}
+                    else 
+						returnValue = new Key(modifiersToString(modifiers), 0, ' ');
 				}
 				else
 				{
@@ -128,9 +115,6 @@ public class KeyEventTranslator
 		case KeyEvent.KEY_TYPED:
 			char ch = evt.getKeyChar();
 
-			if(KeyEventWorkaround.isMacControl(evt))
-				ch |= 0x60;
-
 			switch(ch)
 			{
 			case '\n':
@@ -138,11 +122,7 @@ public class KeyEventTranslator
 			case '\b':
 				return null;
 			case ' ':
-                if (Debug.ALTERNATIVE_DISPATCHER && (modifiers & ~InputEvent.META_MASK) == 0)
-                    returnValue = new Key(
-                        modifiersToString(modifiers),
-                        0,' ');
-				else if((modifiers & ~InputEvent.SHIFT_MASK) != 0)
+                if ((modifiers & ~InputEvent.SHIFT_MASK) != 0)
 					return null;
 			}
 
@@ -163,15 +143,8 @@ public class KeyEventTranslator
 
 			if((modifiers & InputEvent.ALT_GRAPH_MASK) == 0
 				&& (modifiers & ~ignoreMods) != 0)
-			{
-				if(Debug.ALTERNATIVE_DISPATCHER)
-				{
-					returnValue = new Key(
-						modifiersToString(modifiers),
-						0,ch);
-				}
-				else
-					return null;
+			{				
+				return null;
 			}
 			else
 			{
@@ -316,13 +289,13 @@ public class KeyEventTranslator
 	 *
 	 * You can map more than one Java modifier to a symobolic modifier, for
 	 * example :
-	 * <p><code><pre>
-	 *	setModifierMapping(
-	 *		InputEvent.CTRL_MASK,
-	 *		InputEvent.ALT_MASK | InputEvent.META_MASK,
-	 *		0,
-	 *		InputEvent.SHIFT_MASK);
-	 *<pre></code></p>
+	 * <p><code>
+	 	setModifierMapping(
+	 		InputEvent.CTRL_MASK,
+	 		InputEvent.ALT_MASK | InputEvent.META_MASK,
+	 		0,
+	 		InputEvent.SHIFT_MASK);
+	   </code></p>
 	 *
 	 * You cannot map a Java modifer to more than one symbolic modifier.
 	 *
@@ -401,10 +374,10 @@ public class KeyEventTranslator
 	{
 		StringBuilder buf = null;
 
-		for(int i = 0; i < MODS.length; i++)
+		for (int modifier : MODS)
 		{
-			if((mods & MODS[i]) != 0)
-				buf = lazyAppend(buf,getSymbolicModifierName(MODS[i]));
+			if ((mods & modifier) != 0)
+				buf = lazyAppend(buf, getSymbolicModifierName(modifier));
 		}
 
 		if(buf == null)
@@ -530,7 +503,7 @@ public class KeyEventTranslator
 
 		private final int hashCode;
 		/**
-			Wether this Key event applies to all jEdit windows (and not only a specific jEdit GUI component).
+			Whether this Key event applies to all jEdit windows (and not only a specific jEdit GUI component).
 		*/
 		protected boolean isFromGlobalContext;
 
@@ -554,8 +527,7 @@ public class KeyEventTranslator
 			if(o instanceof Key)
 			{
 				Key k = (Key)o;
-				if(StandardUtilities.objectsEqual(modifiers,
-					k.modifiers) && key == k.key
+				if(Objects.equals(modifiers, k.modifiers) && key == k.key
 					&& input == k.input)
 				{
 					return true;
