@@ -35,7 +35,7 @@ import org.gjt.sp.util.Log;
  * Java's keyboard handling is crap, to put it mildly.
  *
  * @author Slava Pestov
- * @version $Id: KeyEventWorkaround.java 22842 2013-03-14 21:38:44Z elberry $
+ * @version $Id: KeyEventWorkaround.java 24092 2015-09-24 02:36:15Z ezust $
  */
 public class KeyEventWorkaround
 {
@@ -129,7 +129,7 @@ public class KeyEventWorkaround
 		case KeyEvent.VK_OPEN_BRACKET :
 		case KeyEvent.VK_BACK_SLASH   :
 		case KeyEvent.VK_CLOSE_BRACKET:
-	/*	case KeyEvent.VK_NUMPAD0 :
+		case KeyEvent.VK_NUMPAD0 :
 		case KeyEvent.VK_NUMPAD1 :
 		case KeyEvent.VK_NUMPAD2 :
 		case KeyEvent.VK_NUMPAD3 :
@@ -144,7 +144,7 @@ public class KeyEventWorkaround
 		case KeyEvent.VK_SEPARATOR:
 		case KeyEvent.VK_SUBTRACT   :
 		case KeyEvent.VK_DECIMAL    :
-		case KeyEvent.VK_DIVIDE     :*/
+		case KeyEvent.VK_DIVIDE     :
 		case KeyEvent.VK_BACK_QUOTE:
 		case KeyEvent.VK_QUOTE:
 		case KeyEvent.VK_DEAD_GRAVE:
@@ -188,44 +188,6 @@ public class KeyEventWorkaround
 		}
 	} //}}}
 
-	//{{{ isMacControl() method
-	/**
-	 * Apple sucks.
-	 */
-	public static boolean isMacControl(KeyEvent evt)
-	{
-		return (OperatingSystem.isMacOS() &&
-			(evt.getModifiers() & InputEvent.CTRL_MASK) != 0
-			&& evt.getKeyChar() <= 0x2B);
-	} //}}}
-
-	//{{{ isNumericKeypad() method
-	public static boolean isNumericKeypad(int keyCode)
-	{
-		switch(keyCode)
-		{
-		case KeyEvent.VK_NUMPAD0:
-		case KeyEvent.VK_NUMPAD1:
-		case KeyEvent.VK_NUMPAD2:
-		case KeyEvent.VK_NUMPAD3:
-		case KeyEvent.VK_NUMPAD4:
-		case KeyEvent.VK_NUMPAD5:
-		case KeyEvent.VK_NUMPAD6:
-		case KeyEvent.VK_NUMPAD7:
-		case KeyEvent.VK_NUMPAD8:
-		case KeyEvent.VK_NUMPAD9:
-		case KeyEvent.VK_MULTIPLY:
-		case KeyEvent.VK_ADD:
-		/* case KeyEvent.VK_SEPARATOR: */
-		case KeyEvent.VK_SUBTRACT:
-		case KeyEvent.VK_DECIMAL:
-		case KeyEvent.VK_DIVIDE:
-			return true;
-		default:
-			return false;
-		}
-	} //}}}
-
 	//{{{ processKeyEvent() method
 	public static KeyEvent processKeyEvent(KeyEvent evt)
 	{
@@ -269,10 +231,7 @@ public class KeyEventWorkaround
 						return null;
 				}
 
-				if(isNumericKeypad(keyCode))
-					last = LAST_NUMKEYPAD;
-				else
-					last = LAST_NOTHING;
+				last = LAST_NOTHING;
 
 				break;
 			}
@@ -282,8 +241,7 @@ public class KeyEventWorkaround
 		case KeyEvent.KEY_TYPED:
 			// need to let \b through so that backspace will work
 			// in HistoryTextFields
-			if(!isMacControl(evt)
-				&& (ch < 0x20 || ch == 0x7f || ch == 0xff)
+			if((ch < 0x20 || ch == 0x7f || ch == 0xff)
 				&& ch != '\b' && ch != '\t' && ch != '\n')
 			{
 				return null;
@@ -295,33 +253,18 @@ public class KeyEventWorkaround
 					+ AbstractInputHandler.toString(evt)+": last="+last+".");
 			}
 
-			if(!Debug.ALTERNATIVE_DISPATCHER)
+			if((modifiers & InputEvent.CTRL_MASK) != 0
+				&& (modifiers & InputEvent.ALT_MASK) == 0
+				|| (modifiers & InputEvent.CTRL_MASK) == 0
+				&& (modifiers & InputEvent.ALT_MASK) != 0
+				&& !Debug.ALT_KEY_PRESSED_DISABLED
+				|| (modifiers & InputEvent.META_MASK) != 0)
 			{
-				if((modifiers & InputEvent.CTRL_MASK) != 0
-					&& (modifiers & InputEvent.ALT_MASK) == 0
-					|| (modifiers & InputEvent.CTRL_MASK) == 0
-					&& (modifiers & InputEvent.ALT_MASK) != 0
-					&& !Debug.ALT_KEY_PRESSED_DISABLED
-					|| (modifiers & InputEvent.META_MASK) != 0)
-				{
-					return null;
-				}
+				return null;
 			}
 
-			// if the last key was a numeric keypad key
-			// and NumLock is off, filter it out
-			if(last == LAST_NUMKEYPAD)
-			{
-				last = LAST_NOTHING;
-				if((ch >= '0' && ch <= '9') || ch == '.'
-					|| ch == '/' || ch == '*'
-					|| ch == '-' || ch == '+')
-				{
-					return null;
-				}
-			}
 			// Windows JDK workaround
-			else if(last == LAST_ALT)
+			if(last == LAST_ALT)
 			{
 				last = LAST_NOTHING;
 				switch(ch)
@@ -378,20 +321,9 @@ public class KeyEventWorkaround
 		return evt;
 	} //}}}
 
-	//{{{ numericKeypadKey() method
-	/**
-	 * A workaround for non-working NumLock status in some Java versions.
-	 * @since jEdit 4.0pre8
-	 */
-	public static void numericKeypadKey()
-	{
-		last = LAST_NOTHING;
-	} //}}}
-
 	//{{{ Private members
 	private static int last;
 	private static final int LAST_NOTHING = 0;
-	private static final int LAST_NUMKEYPAD = 1;
-	private static final int LAST_ALT = 2;
+	private static final int LAST_ALT = 1;
 	//}}}
 }
