@@ -37,7 +37,7 @@ import org.gjt.sp.util.ThreadUtilities;
 //}}}
 
 /** Activity Log Viewer
- * @version $Id: LogViewer.java 24429 2016-06-23 03:08:58Z daleanson $
+ * @version $Id: LogViewer.java 24740 2017-09-20 17:16:54Z daleanson $
  */
 public class LogViewer extends JPanel implements DefaultFocusComponent
 {
@@ -115,7 +115,8 @@ public class LogViewer extends JPanel implements DefaultFocusComponent
 		});
 		caption.add(settings);
 
-		ListModel model = Log.getLogListModel();
+		Log.setMaxLines(jEdit.getIntegerProperty("log-viewer.maxlines", 500));
+		ListModel<String> model = Log.getLogListModel();
 		listModel = new MyFilteredListModel(model);
 		// without this, listModel is held permanently in model.
 		// See addNotify() and removeNotify(), and constructor of
@@ -124,10 +125,10 @@ public class LogViewer extends JPanel implements DefaultFocusComponent
 
 		list = new LogList(listModel);
 		listModel.setList(list);
-		cellRenderer = new ColorizerCellRenderer();
+		cellRenderer = new ColorizerCellRenderer(list);
 		list.setCellRenderer(cellRenderer);
 		setFilter();
-
+                                                                    
 		add(BorderLayout.NORTH,caption);
 		JScrollPane scroller = new JScrollPane(list);
 		Dimension dim = scroller.getPreferredSize();
@@ -158,7 +159,7 @@ public class LogViewer extends JPanel implements DefaultFocusComponent
 	public void addNotify()
 	{
 		super.addNotify();
-		cellRenderer.updateColors();
+		cellRenderer.updateColors(list);
 		ListModel model = Log.getLogListModel();
 		model.addListDataListener(listModel);
 		model.addListDataListener(listHandler = new ListHandler());
@@ -189,8 +190,8 @@ public class LogViewer extends JPanel implements DefaultFocusComponent
 
 	//{{{ Private members
 	private ListHandler listHandler;
-	private final FilteredListModel<ListModel<String>> listModel;
-	private final JList list;
+	private FilteredListModel<ListModel<String>> listModel;
+	private final JList<String> list;
 	private final JButton copy;
 	private final JCheckBox tail;
 	private final JTextField filter;
@@ -212,7 +213,7 @@ public class LogViewer extends JPanel implements DefaultFocusComponent
 	//{{{ propertiesChanged() method
 	private void propertiesChanged()
 	{
-		cellRenderer.updateColors();
+		cellRenderer.updateColors(list);
 		list.setFont(jEdit.getFontProperty("view.font"));
 		list.setFixedCellHeight(list.getFontMetrics(list.getFont())
 					.getHeight());
@@ -265,6 +266,7 @@ public class LogViewer extends JPanel implements DefaultFocusComponent
 				StringBuilder buf = new StringBuilder();
 				// TODO: list.getSelectedValues is deprecated. Need to finish the
 				// conversion to generics for this class at some point.
+				
 				Object[] selected = list.getSelectedValues();
 				if(selected != null && selected.length != 0)
 				{
@@ -311,10 +313,9 @@ public class LogViewer extends JPanel implements DefaultFocusComponent
 	} //}}}
 
 	//{{{ LogList class
-	@SuppressWarnings({"unchecked"})	// The FilteredListModel needs work
-	private class LogList extends JList
+	private class LogList extends JList<String>
 	{
-		LogList(ListModel model)
+		LogList(ListModel<String> model)
 		{
 			super(model);
 			setVisibleRowCount(24);
@@ -359,31 +360,56 @@ public class LogViewer extends JPanel implements DefaultFocusComponent
 	} //}}}
 
 	//{{{ ColorizerCellRenderer class
-	private static class ColorizerCellRenderer extends JLabel implements ListCellRenderer
+	private static class ColorizerCellRenderer extends JPanel implements ListCellRenderer<String>
 	{
 		private static Color debugColor;
 		private static Color messageColor;
 		private static Color noticeColor;
 		private static Color warningColor;
 		private static Color errorColor;
+		
+		private String text;
+		private int borderWidth = 1;
+		private int baseline;
+		private int width = 0;
+		private int height;
+		
+		private JList list;
 
-		private ColorizerCellRenderer()
+		private ColorizerCellRenderer(JList list)
 		{
-			updateColors();
+			super();
+			this.list = list;
+			updateColors(list);
+		}
+		
+		public Dimension getPreferredSize() 
+		{
+			return new Dimension(width, height);	
+		}
+		
+		public void paint(Graphics g) 
+		{
+			int currentWidth = (int)list.getFontMetrics(list.getFont()).getStringBounds(text, g).getWidth();
+			this.width = Math.max(this.width, currentWidth);
+			g.setColor(getBackground());
+			g.fillRect(0, 0, getWidth(), getHeight());
+			g.setColor(getForeground());
+			g.drawString(text, borderWidth, baseline);
 		}
 
 		// This is the only method defined by ListCellRenderer.
-		// We just reconfigure the JLabel each time we're called.
 		@Override
 		public Component getListCellRendererComponent(
-							      JList list,
-							      Object value,              // value to display
+							      JList<? extends String> list,
+							      String value,              // value to display
 							      int index,                 // cell index
 							      boolean isSelected,        // is the cell selected
 							      boolean cellHasFocus )     // the list and the cell have the focus
 		{
-			String s = value.toString();
-			setText(s);
+			if (value == null)
+				value = "";
+			text = value;
 			if (isSelected)
 			{
 				setBackground(list.getSelectionBackground());
@@ -393,41 +419,44 @@ public class LogViewer extends JPanel implements DefaultFocusComponent
 			{
 				setBackground(list.getBackground());
 				Color color = list.getForeground();
-				if (s.contains("[debug]"))
+				if (text.contains("[debug]"))
 				{
 					color = debugColor;
 				}
-				else if (s.contains("[message]"))
+				else if (text.contains("[message]"))
 				{
 					color = messageColor;
 				}
-				else if (s.contains("[notice]"))
+				else if (text.contains("[notice]"))
 				{
 					color = noticeColor;
 				}
-				else if (s.contains("[warning]"))
+				else if (text.contains("[warning]"))
 				{
 					color = warningColor;
 				}
-				else if (s.contains("[error]"))
+				else if (text.contains("[error]"))
 				{
 					color = errorColor;
 				}
 				setForeground(color);
 			}
-			setEnabled(list.isEnabled());
-			setFont(list.getFont());
-			setOpaque(true);
 			return this;
 		}
 
-		public void updateColors()
+		public void updateColors(JList list)
 		{
+			this.list = list;
 			debugColor = jEdit.getColorProperty("log-viewer.message.debug.color", Color.BLUE);
 			messageColor = jEdit.getColorProperty("log-viewer.message.message.color", Color.BLACK);
 			noticeColor = jEdit.getColorProperty("log-viewer.message.notice.color", Color.GREEN);
 			warningColor = jEdit.getColorProperty("log-viewer.message.warning.color", Color.ORANGE);
 			errorColor = jEdit.getColorProperty("log-viewer.message.error.color", Color.RED);
+			setFont(list.getFont());
+			FontMetrics fm = list.getFontMetrics(list.getFont());
+			baseline = fm.getAscent() + borderWidth;
+			this.width = list.getWidth();
+			this.height = fm.getHeight() + (2 * borderWidth);
 		}
 	} //}}}
 
@@ -450,7 +479,10 @@ public class LogViewer extends JPanel implements DefaultFocusComponent
 		{
 			if (filter == null || filter.isEmpty())
 				return true;
-			String text = delegated.getElementAt(row).toString().toLowerCase();
+			Object item = delegated.getElementAt(row);
+			if (item == null)
+				return true;
+			String text = item.toString().toLowerCase();
 			if (!showDebug && text.contains("[debug]"))
 				return false;
 			if (!showMessage && text.contains("[message]"))
@@ -466,6 +498,7 @@ public class LogViewer extends JPanel implements DefaultFocusComponent
 	} //}}}
 
 	//{{{ LogSettings dialog
+	@SuppressWarnings({"unchecked"})	// The FilteredListModel needs work
 	private class LogSettings extends JDialog
 	{
 		LogSettings()
@@ -553,6 +586,11 @@ public class LogViewer extends JPanel implements DefaultFocusComponent
 				protected void _save()
 				{
 					jEdit.setIntegerProperty("log-viewer.maxlines", ((SpinnerNumberModel)maxLines.getModel()).getNumber().intValue());
+					Log.setMaxLines(jEdit.getIntegerProperty("log-viewer.maxlines", 500));
+					ListModel<String> model = Log.getLogListModel();
+					listModel = new MyFilteredListModel(model);
+					list.setModel(listModel);
+					listModel.setList(list);
 
 					showDebug = debug.isSelected();
 					jEdit.setBooleanProperty("log-viewer.message.debug", showDebug);
@@ -573,7 +611,6 @@ public class LogViewer extends JPanel implements DefaultFocusComponent
 
 					jEdit.setBooleanProperty("debug.beepOnOutput", beep.isSelected());
 
-					setFilter();
 					// it would be most clean to call jEdit.propertiesChanged() now
 					// which is needed since global debug.beepOnOutput flag is attached to this pane;
 					// but to avoid extra log entries, we workaround it by direct Log access
