@@ -28,6 +28,7 @@ import javax.swing.border.*;
 import java.awt.*;
 import java.awt.event.*;
 import org.gjt.sp.jedit.textarea.*;
+import org.gjt.sp.util.GenericGUIUtilities;
 import org.gjt.sp.jedit.*;
 //}}}
 /** Dialog for selection of a range of lines */
@@ -40,12 +41,12 @@ public class SelectLineRange extends EnhancedDialog implements ActionListener
 		this.view = view;
 
 		JPanel content = new JPanel(new BorderLayout());
-		content.setBorder(new EmptyBorder(12,12,12,0));
+		content.setBorder(new EmptyBorder(12, 12, 11, 11));
 		setContentPane(content);
 
 		JLabel label = new JLabel(jEdit.getProperty(
 			"selectlinerange.caption"));
-		label.setBorder(new EmptyBorder(0,0,6,12));
+		label.setBorder(new EmptyBorder(0, 0, 6, 12));
 		content.add(BorderLayout.NORTH,label);
 
 		JPanel panel = createFieldPanel();
@@ -54,22 +55,22 @@ public class SelectLineRange extends EnhancedDialog implements ActionListener
 
 		panel = new JPanel();
 		panel.setLayout(new BoxLayout(panel,BoxLayout.X_AXIS));
-		panel.setBorder(new EmptyBorder(6,0,0,12));
-		panel.add(Box.createGlue());
-		panel.add(Box.createGlue());
+		panel.setBorder(new EmptyBorder(17, 0, 0, 0));
 		ok = new JButton(jEdit.getProperty("common.ok"));
 		ok.addActionListener(this);
 		getRootPane().setDefaultButton(ok);
-		panel.add(ok);
-		panel.add(Box.createHorizontalStrut(6));
 		cancel = new JButton(jEdit.getProperty("common.cancel"));
 		cancel.addActionListener(this);
-		panel.add(cancel);
+		GenericGUIUtilities.makeSameSize(ok, cancel);
+
 		panel.add(Box.createGlue());
+		panel.add(ok);
+		panel.add(Box.createHorizontalStrut(6));
+		panel.add(cancel);
 
 		content.add(panel,BorderLayout.SOUTH);
 
-		GUIUtilities.requestFocus(this,startField);
+		GenericGUIUtilities.requestFocus(this, startField);
 
 		pack();
 		setLocationRelativeTo(view);
@@ -89,7 +90,7 @@ public class SelectLineRange extends EnhancedDialog implements ActionListener
 		}
 		catch(NumberFormatException nf)
 		{
-			getToolkit().beep();
+			javax.swing.UIManager.getLookAndFeel().provideErrorFeedback(null); 
 			return;
 		}
 
@@ -98,7 +99,7 @@ public class SelectLineRange extends EnhancedDialog implements ActionListener
 		if(startLine < 0 || endLine >= buffer.getLineCount()
 			|| startLine > endLine)
 		{
-			getToolkit().beep();
+			javax.swing.UIManager.getLookAndFeel().provideErrorFeedback(null); 
 			return;
 		}
 
@@ -135,8 +136,8 @@ public class SelectLineRange extends EnhancedDialog implements ActionListener
 
 	//{{{ Instance variables
 	private View view;
-	private JTextField startField;
-	private JTextField endField;
+	private NumericTextField startField;
+	private NumericTextField endField;
 	private JButton ok;
 	private JButton cancel;
 	//}}}
@@ -148,7 +149,7 @@ public class SelectLineRange extends EnhancedDialog implements ActionListener
 		JPanel panel = new JPanel(layout);
 
 		GridBagConstraints cons = new GridBagConstraints();
-		cons.insets = new Insets(0,0,6,12);
+		cons.insets = new Insets(0, 0, 6, 6);
 		cons.gridwidth = cons.gridheight = 1;
 		cons.gridx = cons.gridy = 0;
 		cons.fill = GridBagConstraints.BOTH;
@@ -157,7 +158,22 @@ public class SelectLineRange extends EnhancedDialog implements ActionListener
 		layout.setConstraints(label,cons);
 		panel.add(label);
 
-		startField = new JTextField(10);
+		startField = new NumericTextField("0", 10, true);
+		
+		FocusListener focusListener = new FocusListener()
+			{
+				public void focusGained(FocusEvent fe) 
+				{
+					((JTextField)fe.getSource()).selectAll();
+				}
+				
+				public void focusLost(FocusEvent fe)
+				{
+					JTextField source = (JTextField)fe.getSource();
+					source.setCaretPosition(source.getText().length());
+				}
+			};
+		startField.addFocusListener(focusListener);
 		cons.gridx = 1;
 		cons.weightx = 1.0f;
 		layout.setConstraints(startField,cons);
@@ -168,13 +184,14 @@ public class SelectLineRange extends EnhancedDialog implements ActionListener
 		cons.gridx = 0;
 		cons.weightx = 0.0f;
 		cons.gridy = 1;
-		layout.setConstraints(label,cons);
+		layout.setConstraints(label, cons);
 		panel.add(label);
 
-		endField = new JTextField(10);
+		endField = new NumericTextField("0", 10, true);
+		endField.addFocusListener(focusListener);
 		cons.gridx = 1;
 		cons.weightx = 1.0f;
-		layout.setConstraints(endField,cons);
+		layout.setConstraints(endField, cons);
 		panel.add(endField);
 
 		return panel;
