@@ -37,7 +37,7 @@ import javax.swing.text.Segment;
  * Deep indent rule.
  *
  * @author Matthieu Casanova
- * @version $Id: DeepIndentRule.java 21831 2012-06-18 22:54:17Z ezust $
+ * @version $Id: DeepIndentRule.java 24413 2016-06-19 11:07:31Z kerik-sf $
  */
 public class DeepIndentRule implements IndentRule
 {
@@ -182,19 +182,8 @@ public class DeepIndentRule implements IndentRule
 				length = searchPos - offset + 1;
 			}
 
-			switch (id)
+			if(!Token.isCommentOrLiteral(id))
 			{
-			case Token.COMMENT1:
-			case Token.COMMENT2:
-			case Token.COMMENT3:
-			case Token.COMMENT4:
-			case Token.LITERAL1:
-			case Token.LITERAL2:
-			case Token.LITERAL3:
-			case Token.LITERAL4:
-				/* Ignore comments and literals. */
-				break;
-			default:
 				for (int i = offset; i < offset + length; i++)
 				{
 					if (seg.array[seg.offset + i] == openChar)
@@ -212,7 +201,6 @@ public class DeepIndentRule implements IndentRule
 							close.push(i);
 					}
 				}
-				break;
 			}
 		}
 
