@@ -48,7 +48,7 @@ public class VFSFile implements Serializable
 	/**
 	 * Return the index of a file whose name matches the given string,
 	 * in a case-insensitive manner. Exact matches are preferred,
-	 * then same length with different cases, then longest match.
+	 * then same length with different cases, then first found.
 	 * @param files The list of files
 	 * @param start The start index, inclusive
 	 * @param end The end index, exclusive
@@ -61,7 +61,6 @@ public class VFSFile implements Serializable
 	{
 		boolean strIsAbsolute = MiscUtilities.isAbsolutePath(str);
 		int strLen = str.length();
-		int potentialMatchLen = 0;
 		int iPotentialMatch = -1;
 		boolean potentialMatchGTStr = false;
 
@@ -82,15 +81,13 @@ public class VFSFile implements Serializable
 			}
 			else if(matchAgainst.regionMatches(true,0,str,0,strLen))
 			{
-				/* Keep the first match with exact length but different case.
-				 * If the first match is not same length, prefer longest match */
+				// not found yet or not exact length yet and has exact length
 				if(iPotentialMatch == -1
 						|| (potentialMatchGTStr
-							&& (matchAgainst.length() > potentialMatchLen)))
+							&& (matchAgainst.length() == strLen)))
 				{
-					potentialMatchLen = matchAgainst.length();
 					iPotentialMatch = i;
-					potentialMatchGTStr = potentialMatchLen > strLen;
+					potentialMatchGTStr = matchAgainst.length() > strLen;
 				}
 			}
 		}
