@@ -46,7 +46,7 @@ import org.gjt.sp.jedit.io.EncodingServer;
  * Menu provider for actions to reload the current buffer with a
  * specific encoding.
  *
- * @version $Id: ReloadWithEncodingProvider.java 21831 2012-06-18 22:54:17Z ezust $
+ * @version $Id: ReloadWithEncodingProvider.java 24425 2016-06-22 19:29:40Z daleanson $
  */
 public class ReloadWithEncodingProvider implements ActionListener, DynamicMenuProvider
 {	
@@ -118,7 +118,7 @@ public class ReloadWithEncodingProvider implements ActionListener, DynamicMenuPr
 		JMenuItem mi = (JMenuItem) ae.getSource();
 		String action = mi.getActionCommand();
 		String encoding = null;
-		Hashtable props = null;
+		Hashtable<String, Object> props = null;
 
 		if (action.startsWith("encoding@"))
 		{
@@ -147,7 +147,7 @@ public class ReloadWithEncodingProvider implements ActionListener, DynamicMenuPr
 
 		if (encoding != null)
 		{
-			props = new Hashtable();
+			props = new Hashtable<String, Object>();
 			props.put(JEditBuffer.ENCODING, encoding);
 			// Disable auto-detect because user explicitly
 			// specify an encoding.
@@ -157,7 +157,7 @@ public class ReloadWithEncodingProvider implements ActionListener, DynamicMenuPr
 
 		String path = view.getBuffer().getPath();
 		jEdit.closeBuffer(view, view.getBuffer());
-		jEdit.openFile(view,null,path,false,props);
+		jEdit.openFile(view, null, path, false, props);
 	} //}}}
 }
 
