@@ -43,21 +43,22 @@ import org.gjt.sp.util.StandardUtilities;
 
 public class BufferOptionPane extends AbstractOptionPane
 {
-	private JComboBox encoding;
-	private JComboBox lineSeparator;
+	private JComboBox<String> encoding;
+	private JComboBox<String> lineSeparator;
 	private JCheckBox gzipped;
 	private Mode[] modes;
-	private JComboBox mode;
-	private JComboBox folding;
-	private JComboBox wrap;
-	private JComboBox maxLineLen;
-	private JComboBox tabSize;
-	private JComboBox indentSize;
-	private JComboBox checkModStatus;
+	private JComboBox<Mode> mode;
+	private JComboBox<String> folding;
+	private JComboBox<String> wrap;
+	private JComboBox<String> maxLineLen;
+	private JComboBox<String> tabSize;
+	private JComboBox<String> indentSize;
+	private JComboBox<String> checkModStatus;
 	private JCheckBox noTabs;
 	private Buffer buffer;
 	private JCheckBox elasticTabstops;
-	private JComboBox autoIndent;
+	private JComboBox<String> autoIndent;
+	private JCheckBox locked;
 
 	public BufferOptionPane()
 	{
@@ -81,7 +82,7 @@ public class BufferOptionPane extends AbstractOptionPane
 		String[] lineSeps = { jEdit.getProperty("lineSep.unix"),
 			jEdit.getProperty("lineSep.windows"),
 			jEdit.getProperty("lineSep.mac") };
-		lineSeparator = new JComboBox(lineSeps);
+		lineSeparator = new JComboBox<String>(lineSeps);
 		String lineSep = buffer.getStringProperty(JEditBuffer.LINESEP);
 		if(lineSep == null)
 			lineSep = System.getProperty("line.separator");
@@ -98,7 +99,7 @@ public class BufferOptionPane extends AbstractOptionPane
 		//{{{ Encoding
 		String[] encodings = MiscUtilities.getEncodings(true);
 		Arrays.sort(encodings,new StandardUtilities.StringCompare<String>(true));
-		encoding = new JComboBox(encodings);
+		encoding = new JComboBox<String>(encodings);
 		encoding.setEditable(true);
 		encoding.setSelectedItem(buffer.getStringProperty(JEditBuffer.ENCODING));
 		addComponent(jEdit.getProperty("buffer-options.encoding"),
@@ -120,7 +121,7 @@ public class BufferOptionPane extends AbstractOptionPane
 			jEdit.getProperty("options.general.checkModStatus.reload"),
 			jEdit.getProperty("options.general.checkModStatus.silentReload")
 		};
-		checkModStatus = new JComboBox(modCheckOptions);
+		checkModStatus = new JComboBox<String>(modCheckOptions);
 		if(buffer.getAutoReload())
 		{
 			if(buffer.getAutoReloadDialog())
@@ -147,7 +148,7 @@ public class BufferOptionPane extends AbstractOptionPane
 		//{{{ Edit mode
 		modes = jEdit.getModes();
 		Arrays.sort(modes,new StandardUtilities.StringCompare<Mode>(true));
-		mode = new JComboBox(modes);
+		mode = new JComboBox<Mode>(modes);
 		mode.setSelectedItem(buffer.getMode());
 		ActionHandler actionListener = new ActionHandler();
 		mode.addActionListener(actionListener);
@@ -157,7 +158,7 @@ public class BufferOptionPane extends AbstractOptionPane
 		//{{{ Fold mode
 		String[] foldModes = FoldHandler.getFoldModes();
 
-		folding = new JComboBox(foldModes);
+		folding = new JComboBox<String>(foldModes);
 		folding.setSelectedItem(buffer.getStringProperty("folding"));
 		addComponent(jEdit.getProperty("options.editing.folding"),
 			folding);
@@ -165,7 +166,7 @@ public class BufferOptionPane extends AbstractOptionPane
 
 		//{{{ Automatic indentation
 		String[] indentModes = {"none", "simple", "full"};
-		autoIndent = new JComboBox(indentModes);
+		autoIndent = new JComboBox<String>(indentModes);
 		autoIndent.setSelectedItem(buffer.getStringProperty("autoIndent"));
 		addComponent(jEdit.getProperty("options.editing.autoIndent"), autoIndent);
 		//}}}
@@ -177,7 +178,7 @@ public class BufferOptionPane extends AbstractOptionPane
 			"hard"
 		};
 
-		wrap = new JComboBox(wrapModes);
+		wrap = new JComboBox<String>(wrapModes);
 		wrap.setSelectedItem(buffer.getStringProperty("wrap"));
 		addComponent(jEdit.getProperty("options.editing.wrap"),
 			wrap);
@@ -186,7 +187,7 @@ public class BufferOptionPane extends AbstractOptionPane
 		//{{{ Max line length
 		String[] lineLengths = { "0", "72", "76", "80" };
 
-		maxLineLen = new JComboBox(lineLengths);
+		maxLineLen = new JComboBox<String>(lineLengths);
 		maxLineLen.setEditable(true);
 		maxLineLen.setSelectedItem(buffer.getStringProperty("maxLineLen"));
 		addComponent(jEdit.getProperty("options.editing.maxLineLen"),
@@ -195,14 +196,14 @@ public class BufferOptionPane extends AbstractOptionPane
 
 		//{{{ Tab size
 		String[] tabSizes = { "2", "4", "8" };
-		tabSize = new JComboBox(tabSizes);
+		tabSize = new JComboBox<String>(tabSizes);
 		tabSize.setEditable(true);
 		tabSize.setSelectedItem(buffer.getStringProperty("tabSize"));
 		addComponent(jEdit.getProperty("options.editing.tabSize"),tabSize);
 		//}}}
 
 		//{{{ Indent size
-		indentSize = new JComboBox(tabSizes);
+		indentSize = new JComboBox<String>(tabSizes);
 		indentSize.setEditable(true);
 		indentSize.setSelectedItem(buffer.getStringProperty("indentSize"));
 		addComponent(jEdit.getProperty("options.editing.indentSize"),
@@ -223,6 +224,12 @@ public class BufferOptionPane extends AbstractOptionPane
 		elasticTabstops.setSelected(buffer.getBooleanProperty("elasticTabstops"));
 		addComponent(elasticTabstops);
 		//}}}
+
+		//{{{ Locked setting
+		locked = new JCheckBox(jEdit.getProperty("buffer-options.locked"));
+		locked.setSelected(buffer.getBooleanProperty("locked"));
+		addComponent(locked);
+		//}}}
 	} //}}}
 
 	//{{{ _save() method
@@ -304,8 +311,10 @@ public class BufferOptionPane extends AbstractOptionPane
 		buffer.setBooleanProperty("elasticTabstops",elasticTabstops.isSelected());
 		buffer.setStringProperty("autoIndent", (String)autoIndent.getSelectedItem());
 
+		buffer.setBooleanProperty("locked", locked.isSelected()); // requires propertiesChanged() call afterwards
+
 		index = mode.getSelectedIndex();
-		buffer.setMode(modes[index]);
+		buffer.setMode(modes[index]); // NOTE: setMode() makes implicit call of propertiesChanged()
 		switch(checkModStatus.getSelectedIndex())
 		{
 		case 0:
