@@ -32,10 +32,11 @@ import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.ItemEvent;
 import java.awt.event.ItemListener;
+import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Comparator;
 import java.util.HashMap;
-import java.util.Vector;
+import java.util.List;
 
 import javax.swing.Box;
 import javax.swing.DefaultCellEditor;
@@ -78,7 +79,7 @@ public class DockingOptionPane extends AbstractOptionPane
 		add(BorderLayout.SOUTH, createDockingFrameworkChooser());
 
 		dockableSetSelection.setModel(
-			new DefaultComboBoxModel(windowModel.getDockableSets()));
+			new DefaultComboBoxModel<String>(windowModel.getDockableSets().toArray(new String[0])));
 	} //}}}
 
 	//{{{ _save() method
@@ -94,12 +95,11 @@ public class DockingOptionPane extends AbstractOptionPane
 	//{{{ Private members
 
 	//{{{ Instance variables
-	private JComboBox dockingFramework;
-	private JTable windowTable;
+	private JComboBox<String> dockingFramework;
 	private WindowTableModel windowModel;
 	private JCheckBox autoLoadModeLayout;
 	private JCheckBox autoSaveModeLayout;
-	private JComboBox dockableSetSelection;
+	private JComboBox<String> dockableSetSelection;
 	//}}}
 
 	private static final String DOCKING_OPTIONS_PREFIX = "options.docking.";
@@ -112,7 +112,7 @@ public class DockingOptionPane extends AbstractOptionPane
 	{
 		String [] frameworks =
 			ServiceManager.getServiceNames(View.DOCKING_FRAMEWORK_PROVIDER_SERVICE);
-		dockingFramework = new JComboBox(frameworks);
+		dockingFramework = new JComboBox<String>(frameworks);
 
 		String framework = View.getDockingFrameworkName();
 		for (int i = 0; i < frameworks.length; i++)
@@ -165,7 +165,7 @@ public class DockingOptionPane extends AbstractOptionPane
 		setSelection.add(new JLabel(jEdit.getProperty(
 			"options.docking.selectSet.label")));
 		setSelection.add(Box.createHorizontalStrut(6));
-		dockableSetSelection = new JComboBox();
+		dockableSetSelection = new JComboBox<String>();
 		setSelection.add(dockableSetSelection);
 		dockableSetSelection.addItemListener(new ItemListener()
 		{
@@ -182,7 +182,7 @@ public class DockingOptionPane extends AbstractOptionPane
 	private JScrollPane createWindowTableScroller()
 	{
 		windowModel = createWindowModel();
-		windowTable = new JTable(windowModel);
+		JTable windowTable = new JTable(windowModel);
 		windowTable.getTableHeader().setReorderingAllowed(false);
 		windowTable.setColumnSelectionAllowed(false);
 		windowTable.setRowSelectionAllowed(false);
@@ -210,7 +210,7 @@ public class DockingOptionPane extends AbstractOptionPane
 	//}}}
 
 	//{{{ DockPositionCellRenderer class
-	static class DockPositionCellRenderer extends JComboBox
+	static class DockPositionCellRenderer extends JComboBox<String>
 		implements TableCellRenderer
 	{
 		DockPositionCellRenderer()
@@ -243,16 +243,16 @@ class WindowTableModel extends AbstractTableModel
 	private static final String PLUGIN_SET_PREFIX = "Plugin: ";
 	private static final String CORE_DOCKABLE_SET = "Core";
 	private static final String ALL_DOCKABLE_SET = "All";
-	private HashMap<String, Vector<Entry>> dockableSets;
-	private Vector<Entry> windows;
+	private HashMap<String, List<Entry>> dockableSets;
+	private List<Entry> windows;
 
 	//{{{ WindowTableModel constructor
 	WindowTableModel()
 	{
-		dockableSets = new HashMap<String, Vector<Entry>>();
-		Vector<Entry> all = new Vector<Entry>();
+		dockableSets = new HashMap<String, List<Entry>>();
+		List<Entry> all = new ArrayList<Entry>();
 		dockableSets.put(ALL_DOCKABLE_SET, all);
-		windows = new Vector<Entry>();
+		windows = new ArrayList<Entry>();
 		String[] dockables = DockableWindowManager.getRegisteredDockableWindows();
 		for (String dockable: dockables)
 		{
@@ -263,10 +263,10 @@ class WindowTableModel extends AbstractTableModel
 				set = PLUGIN_SET_PREFIX + plugin;
 			else
 				set = CORE_DOCKABLE_SET;
-			Vector<Entry> currentSetDockables = dockableSets.get(set);
+			List<Entry> currentSetDockables = dockableSets.get(set);
 			if (currentSetDockables == null)
 			{
-				currentSetDockables = new Vector<Entry>();
+				currentSetDockables = new ArrayList<Entry>();
 				dockableSets.put(set, currentSetDockables);
 			}
 			Entry entry = new Entry(dockable);
@@ -276,16 +276,16 @@ class WindowTableModel extends AbstractTableModel
 		showSet(ALL_DOCKABLE_SET);
 	} //}}}
 
-	public Vector<String> getDockableSets()
+	public List<String> getDockableSets()
 	{
-		Vector<String> sets = new Vector<String>();
+		List<String> sets = new ArrayList<String>();
 		for (String set: dockableSets.keySet())
 			sets.add(set);
 		sets.remove(ALL_DOCKABLE_SET);
 		sets.remove(CORE_DOCKABLE_SET);
 		Collections.sort(sets);
-		sets.insertElementAt(CORE_DOCKABLE_SET, 0);
-		sets.insertElementAt(ALL_DOCKABLE_SET, 0);
+		sets.add(0, CORE_DOCKABLE_SET);
+		sets.add(0, ALL_DOCKABLE_SET);
 		return sets;
 	}
 
@@ -325,7 +325,7 @@ class WindowTableModel extends AbstractTableModel
 	//{{{ getValueAt() method
 	public Object getValueAt(int row, int col)
 	{
-		Entry window = (Entry)windows.elementAt(row);
+		Entry window = (Entry)windows.get(row);
 		switch(col)
 		{
 		case 0:
@@ -349,7 +349,7 @@ class WindowTableModel extends AbstractTableModel
 		if(col == 0)
 			return;
 
-		Entry window = (Entry)windows.elementAt(row);
+		Entry window = (Entry)windows.get(row);
 		switch(col)
 		{
 		case 1:
@@ -381,7 +381,7 @@ class WindowTableModel extends AbstractTableModel
 	{
 		for(int i = 0; i < windows.size(); i++)
 		{
-			((Entry)windows.elementAt(i)).save();
+			((Entry)windows.get(i)).save();
 		}
 	} //}}}
 
