@@ -35,7 +35,7 @@ import org.gjt.sp.jedit.browser.VFSBrowser;
  * The Save and Backup option panel.
  *
  * @author Slava Pestov
- * @author $Id: SaveBackupOptionPane.java 21831 2012-06-18 22:54:17Z ezust $
+ * @author $Id: SaveBackupOptionPane.java 24843 2018-03-19 00:04:03Z ezust $
  */
 public class SaveBackupOptionPane extends AbstractOptionPane
 {
@@ -49,9 +49,9 @@ public class SaveBackupOptionPane extends AbstractOptionPane
 	@Override
 	protected void _init()
 	{
-		
+
 		/* Save-As Uses FSB */
-		
+
 		saveAsUsesFSB = new JCheckBox(jEdit.getProperty(
 			"options.save-back.saveAsUsesFSB"));
 		saveAsUsesFSB.setSelected(jEdit.getBooleanProperty(
@@ -59,14 +59,14 @@ public class SaveBackupOptionPane extends AbstractOptionPane
 		saveAsUsesFSB.setToolTipText(jEdit.getProperty(
 			"options.save-back.saveAsUsesFSB.tooltip"));
 		addComponent(saveAsUsesFSB);
-		
+
 		/* Two-stage save */
 		twoStageSave = new JCheckBox(jEdit.getProperty(
 			"options.save-back.twoStageSave"));
 		twoStageSave.setSelected(jEdit.getBooleanProperty(
 			"twoStageSave"));
 		twoStageSave.setToolTipText(jEdit.getProperty(
-			
+
 			"options.save-back.twoStageSave.tooltip"));
 		addComponent(twoStageSave);
 
@@ -77,24 +77,6 @@ public class SaveBackupOptionPane extends AbstractOptionPane
 			"confirmSaveAll"));
 		addComponent(confirmSaveAll);
 
-		/* Autosave interval */
-		autosave = new NumericTextField(jEdit.getProperty("autosave"), true);
-		addComponent(jEdit.getProperty("options.save-back.autosave"),autosave);
-
-		/* Autosave untitled buffers */
-		autosaveUntitled = new JCheckBox(jEdit.getProperty(
-			"options.save-back.autosaveUntitled"));
-		autosaveUntitled.setSelected(jEdit.getBooleanProperty("autosaveUntitled"));
-		addComponent(autosaveUntitled);
-
-		suppressNotSavedConfirmUntitled = new JCheckBox(jEdit.getProperty(
-			"options.save-back.suppressNotSavedConfirmUntitled"));
-		suppressNotSavedConfirmUntitled.setToolTipText(jEdit.getProperty(
-			"options.save-back.suppressNotSavedConfirmUntitled.tooltip"));
-		suppressNotSavedConfirmUntitled.setSelected(
-			jEdit.getBooleanProperty("suppressNotSavedConfirmUntitled"));
-		addComponent(suppressNotSavedConfirmUntitled);
-
 		useMD5forDirtyCalculation = new JCheckBox(jEdit.getProperty(
 			"options.save-back.useMD5forDirtyCalculation"));
 		useMD5forDirtyCalculation.setToolTipText(jEdit.getProperty(
@@ -104,23 +86,68 @@ public class SaveBackupOptionPane extends AbstractOptionPane
 		addComponent(useMD5forDirtyCalculation);
 
 
+		/* Close Dirty Untitled Buffers without confirm */
+		suppressNotSavedConfirmUntitled = new JCheckBox(jEdit.getProperty(
+			"options.save-back.suppressNotSavedConfirmUntitled"));
+
+		suppressNotSavedConfirmUntitled.setToolTipText(jEdit.getProperty("options.save-back.suppressNotSavedConfirmUntitled.tooltip"));
+		suppressNotSavedConfirmUntitled.setSelected(jEdit.getBooleanProperty("suppressNotSavedConfirmUntitled"));
+		addComponent(suppressNotSavedConfirmUntitled);
+
+		addSeparator("options.autosave");
+
+		/* Autosave Directory */
+
+		autosaveDirectory = new JTextField(jEdit.getProperty(
+			"autosave.directory"));
+		autosaveDirectory.setToolTipText(
+			jEdit.getProperty("options.save-back.backupDirectory.tooltip"));
+
+		JButton browseAutosaveDirectory = new JButton("...");
+		browseAutosaveDirectory.addActionListener(new MyActionListener2());
+		JPanel panel = new JPanel(new BorderLayout());
+		panel.add(autosaveDirectory);
+		panel.add(browseAutosaveDirectory, BorderLayout.EAST);
+		addComponent(jEdit.getProperty("options.save-back.autosaveDirectory"),
+			panel);
 
 
-		/* Backup count */
-		backups = new NumericTextField(jEdit.getProperty("backups"), true);
-		addComponent(jEdit.getProperty("options.save-back.backups"),backups);
+		/* Autosave untitled buffers */
+		autosaveUntitled = new JCheckBox(jEdit.getProperty(
+			"options.save-back.autosaveUntitled"));
+		autosaveUntitled.setToolTipText(jEdit.getProperty("options.save-back.autosaveUntitled.tooltip"));
+
+		autosaveUntitled.setSelected(jEdit.getBooleanProperty("autosaveUntitled"));
+		addComponent(autosaveUntitled);
+
+		/* Autosave interval */
+		autosave = new NumericTextField(jEdit.getProperty("autosave"), true);
+		autosave.setToolTipText(jEdit.getProperty("options.save-back.autosave.tooltip"));
+		addComponent(jEdit.getProperty("options.save-back.autosave"),autosave);
+
+		addSeparator("options.backup");
 
 		/* Backup directory */
 		backupDirectory = new JTextField(jEdit.getProperty(
 			"backup.directory"));
+		backupDirectory.setToolTipText(
+			jEdit.getProperty("options.save-back.backupDirectory.tooltip"));
+
 		JButton browseBackupDirectory = new JButton("...");
 		browseBackupDirectory.addActionListener(new MyActionListener());
-		JPanel panel = new JPanel(new BorderLayout());
+		panel = new JPanel(new BorderLayout());
 		panel.add(backupDirectory);
 		panel.add(browseBackupDirectory, BorderLayout.EAST);
 		addComponent(jEdit.getProperty("options.save-back.backupDirectory"),
 			panel);
 
+
+		/* Backup count */
+		backups = new NumericTextField(jEdit.getProperty("backups"), true);
+		backups.setToolTipText(jEdit.getProperty("options.save-back.backups.tooltip"));
+		addComponent(jEdit.getProperty("options.save-back.backups"),backups);
+
+
 		/* Backup filename prefix */
 		backupPrefix = new JTextField(jEdit.getProperty("backup.prefix"));
 		addComponent(jEdit.getProperty("options.save-back.backupPrefix"),
@@ -148,15 +175,18 @@ public class SaveBackupOptionPane extends AbstractOptionPane
 		jEdit.setBooleanProperty("confirmSaveAll",confirmSaveAll.isSelected());
 		jEdit.setProperty("autosave", this.autosave.getText());
 		jEdit.setProperty("backups",backups.getText());
+
 		jEdit.setProperty("backup.directory",backupDirectory.getText());
+		String autosaveDirectoryOriginal = jEdit.getProperty("autosave.directory");
+		jEdit.setProperty("autosave.directory", autosaveDirectory.getText());
 		jEdit.setProperty("backup.prefix",backupPrefix.getText());
 		jEdit.setProperty("backup.suffix",backupSuffix.getText());
 		jEdit.setBooleanProperty("backupEverySave", backupEverySave.isSelected());
 		boolean newAutosave = autosaveUntitled.isSelected();
 		boolean oldAutosave = jEdit.getBooleanProperty("autosaveUntitled");
 		jEdit.setBooleanProperty("autosaveUntitled", newAutosave);
-		jEdit.setBooleanProperty("suppressNotSavedConfirmUntitled",
-				suppressNotSavedConfirmUntitled.isSelected());
+		jEdit.setBooleanProperty("suppressNotSavedConfirmUntitled", suppressNotSavedConfirmUntitled.isSelected());
+
 		jEdit.setBooleanProperty("useMD5forDirtyCalculation",
 				useMD5forDirtyCalculation.isSelected());
 		if ((!newAutosave || jEdit.getIntegerProperty("autosave",0) == 0) && oldAutosave)
@@ -170,6 +200,19 @@ public class SaveBackupOptionPane extends AbstractOptionPane
 				}
 			}
 		}
+
+		// if autosave dir changed, we should issue to perform an autosave for all dirty and all untitled buffers
+		// to have the autosaves at the new location
+		if (!autosaveDirectoryOriginal.equals(autosaveDirectory.getText())) {
+			Buffer[] buffers = jEdit.getBuffers();
+			for (Buffer buffer : buffers) {
+				// save dirty
+				if ( buffer.isDirty() ) {
+					buffer.autosave(true);
+				}
+			}
+		}
+
 	} //}}}
 
 	//{{{ Private members
@@ -179,8 +222,10 @@ public class SaveBackupOptionPane extends AbstractOptionPane
 	private JTextField autosave;
 	private JCheckBox autosaveUntitled;
 	private JCheckBox suppressNotSavedConfirmUntitled;
+
 	private JCheckBox useMD5forDirtyCalculation;
 	private JTextField backups;
+	private JTextField autosaveDirectory;
 	private JTextField backupDirectory;
 	private JTextField backupPrefix;
 	private JTextField backupSuffix;
@@ -193,13 +238,25 @@ public class SaveBackupOptionPane extends AbstractOptionPane
 		public void actionPerformed(ActionEvent e)
 		{
 			String[] choosenFolder =
-				GUIUtilities.showVFSFileDialog(null,
-				   			       backupDirectory.getText(),
-				   			       VFSBrowser.CHOOSE_DIRECTORY_DIALOG,
-				   			       false);
+				GUIUtilities.showVFSFileDialog(null, backupDirectory.getText(),
+	   			       	VFSBrowser.CHOOSE_DIRECTORY_DIALOG, false);
 			if (choosenFolder != null)
 				backupDirectory.setText(choosenFolder[0]);
+
 		}
 	} //}}}
 
+	//{{{ MyActionListener class
+	private class MyActionListener2 implements ActionListener
+	{
+		public void actionPerformed(ActionEvent e)
+		{
+			String[] choosenFolder =
+				GUIUtilities.showVFSFileDialog(null, autosaveDirectory.getText(),
+	   			       	VFSBrowser.CHOOSE_DIRECTORY_DIALOG, false);
+			if (choosenFolder != null)
+				autosaveDirectory.setText(choosenFolder[0]);
+
+		}
+	} //}}}
 }
