@@ -3,7 +3,7 @@
  * :tabSize=4:indentSize=4:noTabs=false:
  * :folding=explicit:collapseFolds=1:
  *
- * Copyright (C) 1999, 2000, 2001 Slava Pestov
+ * Copyright © 1999 - 2014 Slava Pestov, Eric Le Lay, Alan Ezust
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,19 +25,25 @@ package org.gjt.sp.jedit.proto.jeditresource;
 //{{{ Imports
 import java.io.File;
 import java.io.FileInputStream;
+import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.InputStream;
 import java.net.URL;
 import java.net.URLConnection;
 
+import javax.annotation.Nonnull;
+
 import org.gjt.sp.jedit.MiscUtilities;
 import org.gjt.sp.jedit.PluginJAR;
 import org.gjt.sp.jedit.jEdit;
-
 import org.gjt.sp.util.Log;
 //}}}
 
 //{{{ class PluginResURLConnection
+/** An implementation of jeditresource:/ url protocol.
+
+	Can be used for accessing jEdit core resources as well.
+*/
 public class PluginResURLConnection extends URLConnection
 {
 	//{{{ constructor
@@ -71,7 +77,11 @@ public class PluginResURLConnection extends URLConnection
 	}//}}}
 
 	//{{{ connect()
-	public void connect() throws IOException
+	/**
+	 * @throws	IOException	on error
+	 * @throws	FileNotFoundException if resource is not found
+	 */
+	public void connect() throws IOException, FileNotFoundException
 	{
 		if(!connected)
 		{
@@ -83,11 +93,10 @@ public class PluginResURLConnection extends URLConnection
 			{
 				boolean pluginFoundInPluginJARs = false;
 				PluginJAR[] plugins = jEdit.getPluginJARs();
-				for(int i = 0; i < plugins.length; i++)
+				for (PluginJAR jar : plugins)
 				{
-					PluginJAR jar = plugins[i];
-					String jarName =MiscUtilities.getFileName(jar.getPath()).toLowerCase(); 
-					if(plugin.equalsIgnoreCase(jarName))
+					String jarName = MiscUtilities.getFileName(jar.getPath()).toLowerCase();
+					if (plugin.equalsIgnoreCase(jarName))
 					{
 						pluginFoundInPluginJARs = true;
 						in = jar.getClassLoader().getResourceAsStream(resource);
@@ -103,19 +112,35 @@ public class PluginResURLConnection extends URLConnection
 
 			if((in == null) && (plugin == null))
 			{
-				// can't find it in jEdit.jar, look for file in jEditHome(). 
+				// can't find it in jEdit.jar, look in getJEditHome().
 				File f = new File(jEdit.getJEditHome(), resource);
-				if (f.exists()) 
+				if (f.exists())
 					in = new FileInputStream(f);
-			if (in == null) throw new IOException("Resource not found: " + plugin + "!" + resource);
 			}
 			connected = true;
 		}
+		if(in == null)
+		{
+			if(plugin != null)
+			{
+				throw new FileNotFoundException("Resource not found: " + plugin + "!" + resource);
+			}
+			else
+			{
+				throw new FileNotFoundException("Resource not found: " + getURL());
+			}
+		}
 	}//}}}
 
 	//{{{ getInputStream()
+	/**
+	 * @return	input stream to read the resource's contents. never null
+	 * @throws	IOException	on error
+	 * @throws	FileNotFoundException if resource is not found
+	 */
+	@Nonnull
 	public InputStream getInputStream()
-		throws IOException
+		throws IOException, FileNotFoundException
 	{
 		connect();
 		return in;
