@@ -30,7 +30,7 @@ import org.gjt.sp.util.Log;
  * Manage the extensions for the gutter and the textarea.
  *
  * @author Slava Pestov
- * @version $Id: ExtensionManager.java 21831 2012-06-18 22:54:17Z ezust $
+ * @version $Id: ExtensionManager.java 23221 2013-09-29 20:03:32Z shlomy $
  */
 class ExtensionManager
 {
@@ -129,11 +129,11 @@ class ExtensionManager
 	//{{{ getToolTipText() method
 	String getToolTipText(int x, int y)
 	{
-		for(int i = 0; i < extensions.size(); i++)
+		for (Entry extension : extensions)
 		{
-			TextAreaExtension ext = extensions.get(i).ext;
-			String toolTip = ext.getToolTipText(x,y);
-			if(toolTip != null)
+			TextAreaExtension ext = extension.ext;
+			String toolTip = ext.getToolTipText(x, y);
+			if (toolTip != null)
 				return toolTip;
 		}
 
